@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleContext.java 20385 2010-11-29 20:25:26Z dfeist $
+ * $Id: DefaultMuleContext.java 22816 2011-09-01 22:02:55Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -9,7 +9,9 @@
  */
 package org.mule;
 
+import org.mule.api.MessagingException;
 import org.mule.api.MuleContext;
+import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleRuntimeException;
 import org.mule.api.client.LocalMuleClient;
@@ -21,6 +23,7 @@ import org.mule.api.context.WorkManager;
 import org.mule.api.context.notification.ServerNotification;
 import org.mule.api.context.notification.ServerNotificationListener;
 import org.mule.api.endpoint.EndpointFactory;
+import org.mule.api.exception.RollbackSourceCallback;
 import org.mule.api.exception.SystemExceptionHandler;
 import org.mule.api.expression.ExpressionManager;
 import org.mule.api.lifecycle.Disposable;
@@ -33,6 +36,7 @@ import org.mule.api.registry.MuleRegistry;
 import org.mule.api.registry.RegistrationException;
 import org.mule.api.registry.Registry;
 import org.mule.api.security.SecurityManager;
+import org.mule.api.store.ListableObjectStore;
 import org.mule.api.transaction.TransactionManagerFactory;
 import org.mule.client.DefaultLocalMuleClient;
 import org.mule.config.DefaultMuleConfiguration;
@@ -46,17 +50,25 @@ import org.mule.lifecycle.MuleContextLifecycleManager;
 import org.mule.management.stats.AllStatistics;
 import org.mule.registry.DefaultRegistryBroker;
 import org.mule.registry.MuleRegistryHelper;
+import org.mule.transport.DefaultPollingController;
+import org.mule.transport.PollingController;
 import org.mule.util.ApplicationShutdownSplashScreen;
 import org.mule.util.ApplicationStartupSplashScreen;
 import org.mule.util.ServerShutdownSplashScreen;
 import org.mule.util.ServerStartupSplashScreen;
 import org.mule.util.SplashScreen;
+import org.mule.util.UUID;
 import org.mule.util.queue.QueueManager;
 
+import java.io.Serializable;
 import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Set;
 
 import javax.resource.spi.work.WorkListener;
 import javax.transaction.TransactionManager;
+import javax.xml.namespace.QName;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -105,12 +117,20 @@ public class DefaultMuleContext implements MuleContext
     private ExpressionManager expressionManager;
 
     private ClassLoader executionClassLoader;
-    
+
     protected LocalMuleClient localMuleClient;
-    
+
     /** Global exception handler which handles "system" exceptions (i.e., when no message is involved). */
     protected SystemExceptionHandler exceptionListener;
 
+    private String clusterId = "";
+
+    private int clusterNodeId;
+
+    private PollingController pollingController = new DefaultPollingController();
+
+    private Map<QName, Set<Object>> configurationAnnotations;
+
     public DefaultMuleContext(MuleConfiguration config,
                               WorkManager workManager,
                               WorkListener workListener,
@@ -131,6 +151,7 @@ public class DefaultMuleContext implements MuleContext
         muleRegistryHelper = createRegistryHelper(registryBroker);
         localMuleClient = new DefaultLocalMuleClient(this);
         exceptionListener = new DefaultSystemExceptionStrategy(this);
+        configurationAnnotations = new HashMap<QName, Set<Object>>();
     }
 
     protected DefaultRegistryBroker createRegistryBroker()
@@ -456,10 +477,10 @@ public class DefaultMuleContext implements MuleContext
         QueueManager queueManager = (QueueManager) registryBroker.lookupObject(MuleProperties.OBJECT_QUEUE_MANAGER);
         if (queueManager == null)
         {
-            Collection temp = registryBroker.lookupObjects(QueueManager.class);
+            Collection<QueueManager> temp = registryBroker.lookupObjects(QueueManager.class);
             if (temp.size() > 0)
             {
-                queueManager = ((QueueManager) temp.iterator().next());
+                queueManager = temp.iterator().next();
             }
         }
         return queueManager;
@@ -539,7 +560,7 @@ public class DefaultMuleContext implements MuleContext
     {
         if (lifecycleManager.isPhaseComplete(phase))
         {
-            throw new IllegalStateException("Cannot set property: '" + propertyName + "' once the server has been gone through the " + phase + " phase.");
+            throw new IllegalStateException("Cannot set property: '" + propertyName + "' once the server has already been through the " + phase + " phase.");
         }
     }
 
@@ -638,6 +659,24 @@ public class DefaultMuleContext implements MuleContext
         return localMuleClient;
     }
 
+    public void handleException(Exception e, RollbackSourceCallback rollbackMethod)
+    {
+        if (e instanceof MessagingException)
+        {
+            MuleEvent event = ((MessagingException) e).getEvent();
+            event.getFlowConstruct().getExceptionListener().handleException(e, event, rollbackMethod);
+        }
+        else
+        {
+            getExceptionListener().handleException(e, rollbackMethod);
+        }
+    }
+    
+    public void handleException(Exception e)
+    {
+        handleException(e, null);
+    }
+    
     public SystemExceptionHandler getExceptionListener()
     {
         return exceptionListener;
@@ -652,4 +691,53 @@ public class DefaultMuleContext implements MuleContext
     {
         return (EndpointFactory) registryBroker.lookupObject(MuleProperties.OBJECT_MULE_ENDPOINT_FACTORY);
     }
+
+    public void setObjectStore(String name, ListableObjectStore<Serializable> store) throws RegistrationException
+    {
+        checkLifecycleForPropertySet(name, Initialisable.PHASE_NAME);
+        registryBroker.registerObject(name, store);
+    }
+
+    public String getClusterId()
+    {
+        return clusterId;
+    }
+
+    public void setClusterId(String clusterId)
+    {
+        this.clusterId = clusterId;
+    }
+
+    public int getClusterNodeId()
+    {
+        return clusterNodeId;
+    }
+
+    public void setClusterNodeId(int clusterNodeId)
+    {
+        this.clusterNodeId = clusterNodeId;
+    }
+
+    public void setPollingController(PollingController pollingController)
+    {
+        this.pollingController = pollingController;
+    }
+
+    @Override
+    public boolean isPrimaryPollingInstance()
+    {
+        return pollingController.isPrimaryPollingInstance();
+    }
+
+    @Override
+    public String getUniqueIdString()
+    {
+        return clusterNodeId + "-" + UUID.getUUID();
+    }
+
+    @Override
+    public Map<QName, Set<Object>> getConfigurationAnnotations()
+    {
+        return configurationAnnotations;
+    }
 }
