@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleMessage.java 20137 2010-11-09 20:38:58Z mike.schilling $
+ * $Id: DefaultMuleMessage.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -42,6 +42,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
+import java.io.Reader;
 import java.io.Serializable;
 import java.net.URL;
 import java.util.ArrayList;
@@ -51,14 +52,14 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicReference;
 
 import javax.activation.DataHandler;
 import javax.activation.FileDataSource;
 
-import edu.emory.mathcs.backport.java.util.concurrent.ConcurrentHashMap;
-import edu.emory.mathcs.backport.java.util.concurrent.CopyOnWriteArrayList;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicBoolean;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicReference;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -70,7 +71,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
 {
     protected static final String NOT_SET = "<not set>";
 
-    private static final long serialVersionUID = 1541720810851984844L;
+    private static final long serialVersionUID = 1541720810851984845L;
     private static final Log logger = LogFactory.getLog(DefaultMuleMessage.class);
     private static final List<Class<?>> consumableClasses = new ArrayList<Class<?>>();
 
@@ -79,6 +80,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
      * message id, this uuid will be ignored
      */
     private String id = UUID.getUUID();
+    private String rootId = id;
 
     private transient Object payload;
     private transient Object originalPayload;
@@ -97,14 +99,12 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * Collection of attachments that were attached to the incoming message
      */
-    @SuppressWarnings("unchecked")
-    private Map<String, DataHandler> inboundAttachments = new ConcurrentHashMap();
+    private transient Map<String, DataHandler> inboundAttachments = new ConcurrentHashMap<String, DataHandler>();
 
     /**
      * Collection of attachments that will be sent out with this message
      */
-    @SuppressWarnings("unchecked")
-    private Map<String, DataHandler> outboundAttachments = new ConcurrentHashMap();
+    private transient Map<String, DataHandler> outboundAttachments = new ConcurrentHashMap<String, DataHandler>();
 
     private transient List<Integer> appliedTransformerHashCodes;
     private transient byte[] cache;
@@ -112,7 +112,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
 
     // these are transient because serialisation generates a new instance
     // so we allow mutation again (and we can't serialize threads anyway)
-    private transient AtomicReference ownerThread = null;
+    private transient AtomicReference<Thread> ownerThread = null;
     private transient AtomicBoolean mutable = null;
 
     private DataType<?> dataType;
@@ -122,6 +122,8 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         addToConsumableClasses("javax.xml.stream.XMLStreamReader");
         addToConsumableClasses("javax.xml.transform.stream.StreamSource");
         consumableClasses.add(OutputHandler.class);
+        consumableClasses.add(InputStream.class);
+        consumableClasses.add(Reader.class);
     }
 
     private static void addToConsumableClasses(String className)
@@ -148,7 +150,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
 
     public DefaultMuleMessage(Object message, Map<String, Object> outboundProperties, Map<String, DataHandler> attachments, MuleContext muleContext)
     {
-        this(message, null, outboundProperties, attachments, muleContext);   
+        this(message, null, outboundProperties, attachments, muleContext);
     }
 
     public DefaultMuleMessage(Object message, Map<String, Object> inboundProperties,
@@ -184,6 +186,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     public DefaultMuleMessage(Object message, MuleMessage previous, MuleContext muleContext)
     {
         id = previous.getUniqueId();
+        rootId = previous.getMessageRootId();
         setMuleContext(muleContext);
         initAppliedTransformerHashCodes();
         setEncoding(previous.getEncoding());
@@ -285,29 +288,31 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         muleContext = context;
     }
 
-    @SuppressWarnings("unchecked")
     private void initAppliedTransformerHashCodes()
     {
-        appliedTransformerHashCodes = new CopyOnWriteArrayList();
+        appliedTransformerHashCodes = new CopyOnWriteArrayList<Integer>();
     }
 
     /**
      * {@inheritDoc}
      */
+    @Override
     public <T> T getPayload(Class<T> outputType) throws TransformerException
     {
-        return (T) getPayload(DataTypeFactory.create(outputType), getEncoding());
+        return getPayload(DataTypeFactory.create(outputType), getEncoding());
     }
 
 
     /**
      * {@inheritDoc}
      */
+    @Override
     public <T> T getPayload(DataType<T> outputType) throws TransformerException
     {
         return getPayload(outputType, getEncoding());
     }
 
+    @Override
     public MuleContext getMuleContext()
     {
         return muleContext;
@@ -404,6 +409,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public Object getOriginalPayload()
     {
         return originalPayload;
@@ -414,16 +420,19 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         setProperty(key, value, PropertyScope.INBOUND);
     }
 
+    @Override
     public void setInvocationProperty(String key, Object value)
     {
         setProperty(key, value, PropertyScope.INVOCATION);
     }
 
+    @Override
     public void setOutboundProperty(String key, Object value)
     {
         setProperty(key, value, PropertyScope.OUTBOUND);
     }
 
+    @Override
     public void setSessionProperty(String key, Object value)
     {
         setProperty(key, value, PropertyScope.SESSION);
@@ -432,6 +441,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setProperty(String key, Object value, PropertyScope scope)
     {
         assertAccess(WRITE);
@@ -460,6 +470,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public Object getProperty(String key)
     {
@@ -471,6 +482,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public Object removeProperty(String key)
     {
         //TODO
@@ -483,6 +495,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public Object removeProperty(String key, PropertyScope scope)
     {
         assertAccess(WRITE);
@@ -501,6 +514,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
      * @deprecated use {@link #setProperty(String, Object, org.mule.api.transport.PropertyScope)} or
      *             preferrably any of the scope-specific set methods.
      */
+    @Override
     @Deprecated
     public void setProperty(String key, Object value)
     {
@@ -530,47 +544,51 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public final String getPayloadAsString() throws Exception
     {
         assertAccess(READ);
         return getPayloadAsString(getEncoding());
     }
 
-    /**
+     /**
      * {@inheritDoc}
      */
+    @Override
     public String getPayloadForLogging(String encoding)
     {
         try
         {
             return getPayloadAsString(encoding);
         }
-        catch (Exception e) 
+        catch (Exception e)
         {
             // TODO Auto-generated catch block
             return  "[Messaage could not be converted to string]";
         }
-    } 
-    
+    }
+
     /**
      * {@inheritDoc}
      */
+    @Override
     public String getPayloadForLogging()
     {
         try
         {
             return getPayloadAsString();
         }
-        catch (Exception e) 
+        catch (Exception e)
         {
             // TODO Auto-generated catch block
             return  "[Messaage could not be converted to string]";
         }
-    } 
+    }
 
     /**
      * {@inheritDoc}
      */
+    @Override
     public byte[] getPayloadAsBytes() throws Exception
     {
         assertAccess(READ);
@@ -589,6 +607,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public String getPayloadAsString(String encoding) throws Exception
     {
         assertAccess(READ);
@@ -609,6 +628,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
      *
      * @deprecated use {@link #getPropertyNames(org.mule.api.transport.PropertyScope)}
      */
+    @Override
     @Deprecated
     public Set<String> getPropertyNames()
     {
@@ -621,6 +641,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public Set<String> getPropertyNames(PropertyScope scope)
     {
         assertAccess(READ);
@@ -641,21 +662,25 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         }
     }
 
+    @Override
     public Set<String> getInvocationPropertyNames()
     {
         return getPropertyNames(PropertyScope.INVOCATION);
     }
 
+    @Override
     public Set<String> getInboundPropertyNames()
     {
         return getPropertyNames(PropertyScope.INBOUND);
     }
 
+    @Override
     public Set<String> getOutboundPropertyNames()
     {
         return getPropertyNames(PropertyScope.OUTBOUND);
     }
 
+    @Override
     public Set<String> getSessionPropertyNames()
     {
         return getPropertyNames(PropertyScope.SESSION);
@@ -666,6 +691,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public String getUniqueId()
     {
         assertAccess(READ);
@@ -678,9 +704,34 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         id = uid;
     }
 
+    @Override
+    public String getMessageRootId()
+    {
+        assertAccess(READ);
+        return rootId;
+    }
+
+    @Override
+    public void setMessageRootId(String rid)
+    {
+        assertAccess(WRITE);
+        rootId = rid;
+    }
+
+    @Override
+    public void propagateRootId(MuleMessage parent)
+    {
+        assertAccess(WRITE);
+        if (parent != null)
+        {
+            rootId = parent.getMessageRootId();
+        }
+    }
+
     /**
      * {@inheritDoc}
      */
+    @Override
     public Object getProperty(String name, Object defaultValue)
     {
         //TODO logger.warn("MuleMessage.getProperty() method is deprecated, use MuleMessage.getOutboundProperty() instead.  This method will be removed in the next point release");
@@ -692,6 +743,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @SuppressWarnings("unchecked")
     public <T> T getProperty(String name, PropertyScope scope)
     {
@@ -699,41 +751,49 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         return (T) properties.getProperty(name, scope);
     }
 
+    @Override
     public <T> T getInboundProperty(String name, T defaultValue)
     {
         return getProperty(name, PropertyScope.INBOUND, defaultValue);
     }
 
+    @Override
     public <T> T getInboundProperty(String name)
     {
         return getProperty(name, PropertyScope.INBOUND, (T) null);
     }
 
+    @Override
     public <T> T getInvocationProperty(String name, T defaultValue)
     {
         return getProperty(name, PropertyScope.INVOCATION, defaultValue);
     }
 
+    @Override
     public <T> T getInvocationProperty(String name)
     {
         return getInvocationProperty(name, (T) null);
     }
 
+    @Override
     public <T> T getOutboundProperty(String name, T defaultValue)
     {
         return getProperty(name, PropertyScope.OUTBOUND, defaultValue);
     }
 
+    @Override
     public <T> T getOutboundProperty(String name)
     {
         return getOutboundProperty(name, (T) null);
     }
 
+    @Override
     public <T> T getSessionProperty(String name, T defaultValue)
     {
         return getProperty(name, PropertyScope.SESSION, defaultValue);
     }
 
+    @Override
     public <T> T getSessionProperty(String name)
     {
         return getSessionProperty(name, (T) null);
@@ -742,6 +802,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @SuppressWarnings("unchecked")
     public <T> T getProperty(String name, PropertyScope scope, T defaultValue)
     {
@@ -780,7 +841,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         }
         else if (defaultValue instanceof String)
         {
-            result = (T) (String) ObjectUtils.getString(getProperty(name, scope), (String) defaultValue);
+            result = (T) ObjectUtils.getString(getProperty(name, scope), (String) defaultValue);
         }
         else
         {
@@ -809,6 +870,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setCorrelationId(String id)
     {
         assertAccess(WRITE);
@@ -825,6 +887,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public String getCorrelationId()
     {
         assertAccess(READ);
@@ -840,6 +903,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setReplyTo(Object replyTo)
     {
         assertAccess(WRITE);
@@ -857,6 +921,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public Object getReplyTo()
     {
         assertAccess(READ);
@@ -872,6 +937,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public int getCorrelationSequence()
     {
         assertAccess(READ);
@@ -885,6 +951,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setCorrelationSequence(int sequence)
     {
         assertAccess(WRITE);
@@ -894,6 +961,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public int getCorrelationGroupSize()
     {
         assertAccess(READ);
@@ -907,6 +975,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setCorrelationGroupSize(int size)
     {
         assertAccess(WRITE);
@@ -916,6 +985,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public ExceptionPayload getExceptionPayload()
     {
         assertAccess(READ);
@@ -925,6 +995,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setExceptionPayload(ExceptionPayload exceptionPayload)
     {
         assertAccess(WRITE);
@@ -967,6 +1038,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void addAttachment(String name, DataHandler dataHandler) throws Exception
     {
@@ -977,6 +1049,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void removeAttachment(String name) throws Exception
     {
@@ -987,6 +1060,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public DataHandler getAttachment(String name)
     {
@@ -997,6 +1071,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public Set<String> getAttachmentNames()
     {
@@ -1004,6 +1079,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         return getInboundAttachmentNames();
     }
 
+    @Override
     public void addOutboundAttachment(String name, DataHandler dataHandler) throws Exception
     {
         assertAccess(WRITE);
@@ -1019,6 +1095,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         inboundAttachments.put(name, dataHandler);
     }
 
+    @Override
     public void addOutboundAttachment(String name, Object object, String contentType) throws Exception
     {
         assertAccess(WRITE);
@@ -1053,36 +1130,42 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         outboundAttachments.put(name, dh);
     }
 
+    @Override
     public void removeOutboundAttachment(String name) throws Exception
     {
         assertAccess(WRITE);
         outboundAttachments.remove(name);
     }
 
+    @Override
     public DataHandler getInboundAttachment(String name)
     {
         assertAccess(READ);
         return inboundAttachments.get(name);
     }
 
+    @Override
     public DataHandler getOutboundAttachment(String name)
     {
         assertAccess(READ);
         return outboundAttachments.get(name);
     }
 
+    @Override
     public Set<String> getInboundAttachmentNames()
     {
         assertAccess(READ);
         return Collections.unmodifiableSet(inboundAttachments.keySet());
     }
 
+    @Override
     public Set<String> getOutboundAttachmentNames()
     {
         assertAccess(READ);
         return Collections.unmodifiableSet(outboundAttachments.keySet());
     }
 
+    @Override
     @SuppressWarnings("unchecked")
     public <T> T findPropertyInAnyScope(String name, T defaultValue)
     {
@@ -1101,6 +1184,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public String getEncoding()
     {
         assertAccess(READ);
@@ -1127,6 +1211,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void setEncoding(String encoding)
     {
         assertAccess(WRITE);
@@ -1157,6 +1242,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void addProperties(Map<String, Object> props)
     {
         addProperties(props, properties.getDefaultScope());
@@ -1165,6 +1251,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void addProperties(Map<String, Object> props, PropertyScope scope)
     {
         assertAccess(WRITE);
@@ -1188,6 +1275,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void clearProperties()
     {
         assertAccess(WRITE);
@@ -1199,6 +1287,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void clearProperties(PropertyScope scope)
     {
         assertAccess(WRITE);
@@ -1209,6 +1298,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public Object getPayload()
     {
         return payload;
@@ -1217,6 +1307,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public synchronized void setPayload(Object payload)
     {
         if (payload == null)
@@ -1233,6 +1324,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void release()
     {
         cache = null;
@@ -1242,6 +1334,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void applyTransformers(MuleEvent event, List<? extends Transformer> transformers) throws MuleException
     {
         applyTransformers(event, transformers, null);
@@ -1250,11 +1343,13 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void applyTransformers(MuleEvent event, Transformer... transformers) throws MuleException
     {
         applyTransformers(event, Arrays.asList(transformers), null);
     }
 
+    @Override
     public void applyTransformers(MuleEvent event, List<? extends Transformer> transformers, Class<?> outputType) throws MuleException
     {
         if (!transformers.isEmpty() && !appliedTransformerHashCodes.contains(transformers.hashCode()))
@@ -1315,13 +1410,19 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
 
                     if (result instanceof MuleMessage)
                     {
-                        synchronized (this)
+                        if (!result.equals(this))
                         {
-                            MuleMessage resultMessage = (MuleMessage) result;
-                            setPayload(resultMessage.getPayload());
-                            originalPayload = resultMessage.getOriginalPayload();
-                            copyMessageProperties(resultMessage);
-                            copyAttachments(resultMessage);
+                            // Only copy the payload and properties of mule message
+                            // transformer result if the message is a different
+                            // instance
+                            synchronized (this)
+                            {
+                                MuleMessage resultMessage = (MuleMessage) result;
+                                setPayload(resultMessage.getPayload());
+                                originalPayload = resultMessage.getOriginalPayload();
+                                copyMessageProperties(resultMessage);
+                                copyAttachments(resultMessage);
+                            }
                         }
                     }
                     else
@@ -1361,6 +1462,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public ThreadSafeAccess newThreadCopy()
     {
         return new DefaultMuleMessage(this);
@@ -1369,6 +1471,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void resetAccessControl()
     {
         // just reset the internal state here as this method is explicitly intended not to
@@ -1386,6 +1489,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     public void assertAccess(boolean write)
     {
         if (AccessControl.isAssertMessageAccess())
@@ -1400,7 +1504,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     {
         if (null == ownerThread)
         {
-            ownerThread = new AtomicReference();
+            ownerThread = new AtomicReference<Thread>();
         }
         if (null == mutable)
         {
@@ -1492,10 +1596,61 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         return isConsumedFromAdditional(this.getPayload().getClass());
     }
 
+    public static class SerializedDataHandler implements Serializable
+    {
+        private static final long serialVersionUID = 1L;
+
+        private DataHandler handler;
+        private String contentType;
+        private Object contents;
+
+        public SerializedDataHandler(String name, DataHandler handler, MuleContext muleContext) throws IOException
+        {
+            if (handler != null && !(handler instanceof Serializable))
+            {
+                contentType = handler.getContentType();
+                Object theContent = handler.getContent();
+                if (theContent instanceof Serializable)
+                {
+                    contents = theContent;
+                }
+                else
+                {
+                    try
+                    {
+                        DataType source = DataTypeFactory.createFromObject(theContent);
+                        Transformer transformer = muleContext.getRegistry().lookupTransformer(source, DataType.BYTE_ARRAY_DATA_TYPE);
+                        if (transformer == null)
+                        {
+                            throw new TransformerException(CoreMessages.noTransformerFoundForMessage(source, DataType.BYTE_ARRAY_DATA_TYPE));
+                        }
+                        contents = transformer.transform(theContent);
+                    }
+                    catch(TransformerException ex)
+                    {
+                        String message = String.format(
+                                "Unable to serialize the attachment %s, which is of type %s with contents of type %s",
+                                name, handler.getClass(), theContent.getClass());
+                        logger.error(message);
+                        throw new IOException(message);
+                    }
+                }
+            }
+            else
+            {
+                this.handler = handler;
+            }
+        }
+
+        public DataHandler getHandler()
+        {
+            return contents != null ? new DataHandler(contents, contentType) : handler;
+        }
+    }
+
     private void writeObject(ObjectOutputStream out) throws Exception
     {
         out.defaultWriteObject();
-
         if (payload instanceof Serializable)
         {
             out.writeBoolean(true);
@@ -1508,10 +1663,51 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
             out.writeInt(serializablePayload.length);
             out.write(serializablePayload);
         }
+        out.writeObject(serializeAttachments(inboundAttachments));
+        out.writeObject(serializeAttachments(outboundAttachments));
 
         // TODO: we don't serialize the originalPayload for now
     }
 
+    private Map<String, SerializedDataHandler> serializeAttachments(Map<String, DataHandler> attachments) throws IOException
+    {
+        Map<String, SerializedDataHandler> toWrite;
+        if (attachments == null)
+        {
+            toWrite = null;
+        }
+        else
+        {
+            toWrite = new HashMap<String, SerializedDataHandler>(attachments.size());
+            for (Map.Entry<String, DataHandler> entry : attachments.entrySet())
+            {
+                String name = entry.getKey();
+                toWrite.put(name, new SerializedDataHandler(name, entry.getValue(), muleContext));
+            }
+        }
+
+        return toWrite;
+    }
+
+    private Map<String, DataHandler> deserializeAttachments(Map<String, SerializedDataHandler> attachments) throws IOException
+    {
+        Map<String, DataHandler> toReturn;
+        if (attachments == null)
+        {
+            toReturn = null;
+        }
+        else
+        {
+            toReturn = new HashMap<String, DataHandler>(attachments.size());
+            for (Map.Entry<String, SerializedDataHandler> entry : attachments.entrySet())
+            {
+                toReturn.put(entry.getKey(), entry.getValue().getHandler());
+            }
+        }
+
+        return toReturn;
+    }
+
     private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
     {
         in.defaultReadObject();
@@ -1528,6 +1724,8 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
             in.read(serializedPayload);
             payload = serializedPayload;
         }
+        inboundAttachments = deserializeAttachments((Map<String, SerializedDataHandler>)in.readObject());
+        outboundAttachments = deserializeAttachments((Map<String, SerializedDataHandler>)in.readObject());
     }
 
     /**
@@ -1538,14 +1736,16 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
      * {@link org.mule.transformer.wire.SerializedMuleMessageWireFormat} or the
      * {@link org.mule.transformer.simple.ByteArrayToSerializable} transformer.
      *
-     * @param muleContext the current muleContext instance
+     * @param context the current muleContext instance
      * @throws MuleException if there is an error initializing
      */
-    public void initAfterDeserialisation(MuleContext muleContext) throws MuleException
+    public void initAfterDeserialisation(MuleContext context) throws MuleException
     {
-        this.muleContext = muleContext;
+        this.muleContext = context;
+        initAppliedTransformerHashCodes();
     }
 
+    @Override
     public DataType<?> getDataType()
     {
         return dataType;
@@ -1554,6 +1754,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public int getIntProperty(String name, int defaultValue)
     {
@@ -1565,6 +1766,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public long getLongProperty(String name, long defaultValue)
     {
@@ -1576,6 +1778,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public double getDoubleProperty(String name, double defaultValue)
     {
@@ -1587,6 +1790,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public boolean getBooleanProperty(String name, boolean defaultValue)
     {
@@ -1598,6 +1802,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void setBooleanProperty(String name, boolean value)
     {
@@ -1609,6 +1814,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void setIntProperty(String name, int value)
     {
@@ -1620,6 +1826,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void setLongProperty(String name, long value)
     {
@@ -1631,6 +1838,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void setDoubleProperty(String name, double value)
     {
@@ -1642,6 +1850,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public String getStringProperty(String name, String defaultValue)
     {
@@ -1653,6 +1862,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     /**
      * {@inheritDoc}
      */
+    @Override
     @Deprecated
     public void setStringProperty(String name, String value)
     {
@@ -1678,9 +1888,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         return null;
     }
 
-    /**
-     * {@inheritDoc}
-     */
+    @Override
     public MuleMessage createInboundMessage() throws Exception
     {
         DefaultMuleMessage newMessage =  new DefaultMuleMessage(getPayload(), this, getMuleContext());
@@ -1688,34 +1896,34 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         return newMessage;
     }
 
-    /*
-     ** copy outbound artifacts to inbound artifacts in the new message
+    /**
+     * copy outbound artifacts to inbound artifacts in the new message
      */
     protected void copyToInbound(DefaultMuleMessage newMessage) throws Exception
     {
-
-        //Copy message, but put all outbound properties and attachments on inbound
-        //We ignore inbound and invocation scopes since the VM receiver needs to behave the
-        //same way as any other receiver in Mule and would only receive inbound headers and attachments
+        // Copy message, but put all outbound properties and attachments on inbound scope.
+        // We ignore inbound and invocation scopes since the VM receiver needs to behave the
+        // same way as any other receiver in Mule and would only receive inbound headers
+        // and attachments
         Map<String, DataHandler> attachments = new HashMap<String, DataHandler>(3);
         for (String name : getOutboundAttachmentNames())
         {
             attachments.put(name, getOutboundAttachment(name));
         }
 
-        Map<String, Object> properties = new HashMap<String, Object>(3);
+        Map<String, Object> newInboundProperties = new HashMap<String, Object>(3);
         for (String name : getOutboundPropertyNames())
         {
-            properties.put(name, getOutboundProperty(name));
+            newInboundProperties.put(name, getOutboundProperty(name));
         }
 
         newMessage.clearProperties(PropertyScope.INBOUND);
         newMessage.clearProperties(PropertyScope.INVOCATION);
         newMessage.clearProperties(PropertyScope.OUTBOUND);
 
-        for (String s : properties.keySet())
+        for (String s : newInboundProperties.keySet())
         {
-            newMessage.setInboundProperty(s, properties.get(s));
+            newMessage.setInboundProperty(s, newInboundProperties.get(s));
         }
 
         newMessage.inboundAttachments.clear();
