@@ -1,5 +1,5 @@
 /*
- * $Id: EndpointNotificationLoggerAgent.java 19446 2010-09-08 13:32:32Z aperepel $
+ * $Id: EndpointNotificationLoggerAgent.java 22162 2011-06-09 18:23:00Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -101,7 +101,7 @@ public class EndpointNotificationLoggerAgent extends AbstractNotificationLoggerA
                     return;
                 }
 
-                MuleEvent event = new DefaultMuleEvent(msg, endpoint, session);
+                MuleEvent event = new DefaultMuleEvent(msg, endpoint.getExchangePattern(), session);
                 endpoint.process(event);
             }
             catch (Exception e1)
