@@ -1,5 +1,5 @@
 /*
- * $Id: MuleEvent.java 21341 2011-02-23 15:59:38Z tcarlson $
+ * $Id: MuleEvent.java 22597 2011-08-05 20:40:24Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,15 +10,17 @@
 
 package org.mule.api;
 
+import org.mule.MessageExchangePattern;
 import org.mule.api.construct.FlowConstruct;
-import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.security.Credentials;
 import org.mule.api.transformer.DataType;
 import org.mule.api.transformer.TransformerException;
+import org.mule.api.transport.ReplyToHandler;
 import org.mule.management.stats.ProcessingTime;
 
 import java.io.OutputStream;
 import java.io.Serializable;
+import java.net.URI;
 
 /**
  * <code>MuleEvent</code> represents any data event occuring in the Mule
@@ -164,13 +166,6 @@ public interface MuleEvent extends Serializable
     @Deprecated
     Object getProperty(String name, Object defaultValue);
 
-    /**
-     * Gets the endpoint associated with this event
-     * 
-     * @return the endpoint associated with this event
-     */
-    ImmutableEndpoint getEndpoint();
-
     /**
      * Retrieves the service session for the current event
      * 
@@ -260,4 +255,48 @@ public interface MuleEvent extends Serializable
      * Returns the times spent processing this event (so far)
      */
     ProcessingTime getProcessingTime();
+    
+    /**
+     * Returns the message exchange pattern for this event
+     */
+    MessageExchangePattern getExchangePattern();
+    
+    /**
+     * Returns true is this event is being processed in a transaction
+     */
+    boolean isTransacted();
+
+    /**
+     * Returns the {@link URI} of the MessageSource that recieved or generated the message being processed.
+     * 
+     * @return
+     */
+    URI getMessageSourceURI();
+
+    /**
+     * Returns the message source name if it has one, otherwise returns toString() of the URI returned be
+     * getMessageSourceURI()
+     * 
+     * @return
+     */
+    String getMessageSourceName();
+
+    /**
+     * Return the replyToHandler (if any) that will be used to perform async reply
+     */
+    ReplyToHandler getReplyToHandler();
+
+    /**
+     * Return the destination (if any) that will be passed to the reply-to handler.
+     */
+    Object getReplyToDestination();
+
+    /**
+     * Set the reply-to destination from the current message, and remove it from the message, to
+     * prevent any further propagation.
+     */
+    void captureReplyToDestination();
+    
+    boolean isSynchronous();
+    
 }
