@@ -1,5 +1,5 @@
 /*
- * $Id: MuleEventContext.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: MuleEventContext.java 22439 2011-07-18 19:06:39Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -21,6 +21,7 @@ import org.mule.api.transformer.DataType;
 import org.mule.api.transformer.TransformerException;
 
 import java.io.OutputStream;
+import java.net.URI;
 
 /**
  * <code>MuleEventContext</code> is the context object for the current request.
@@ -432,7 +433,7 @@ public interface MuleEventContext
      * 
      * @return the receive endpoint for this event context
      */
-    EndpointURI getEndpointURI();
+    URI getEndpointURI();
 
     /**
      * Returns the transaction for the current event or null if there is no
