@@ -1,5 +1,5 @@
 /*
- * $Id: InboundAttachmentsAnnotationTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: InboundAttachmentsAnnotationTestCase.java 22735 2011-08-25 16:02:35Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,33 +10,50 @@
 
 package org.mule.api.annotations.param;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 import org.mule.DefaultMuleMessage;
 import org.mule.api.MuleMessage;
 import org.mule.api.expression.RequiredValueException;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.transformer.types.DataTypeFactory;
+import org.mule.util.ExceptionUtils;
 import org.mule.util.StringDataSource;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
 import javax.activation.DataHandler;
 
-public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+public class InboundAttachmentsAnnotationTestCase extends AbstractServiceAndFlowTestCase
 {
     private MuleMessage muleMessage;
 
-    public InboundAttachmentsAnnotationTestCase()
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        setDisposeManagerPerSuite(true);
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "org/mule/test/annotations/inbound-attachments-annotation-service.xml"},
+            {ConfigVariant.FLOW, "org/mule/test/annotations/inbound-attachments-annotation-flow.xml"}
+
+        });
     }
 
-    @Override
-    protected String getConfigResources()
+    public InboundAttachmentsAnnotationTestCase(ConfigVariant variant, String configResources)
     {
-        return "org/mule/test/annotations/inbound-attachments-annotation.xml";
+        super(variant, configResources);
+        setDisposeContextPerClass(true);
     }
 
     @Override
@@ -44,6 +61,8 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
     {
         super.doSetUp();
         muleMessage  = createMessage(null, null);
+        //These should really be in core, but the @Transformer annotation is not in core
+        muleContext.getRegistry().registerObject("dataHandlerTransformers", new DataHandlerTransformer());
     }
 
     protected MuleMessage createMessage(Map<String, Object> headers, Map<String, DataHandler> attachments) throws Exception
@@ -76,6 +95,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         return message;
     }
 
+    @Test
     public void testSingleAttachment() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -85,12 +105,9 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals("fooValue", ((DataHandler)message.getPayload()).getContent());
     }
 
-
+    @Test
     public void testSingleAttachmentWithType() throws Exception
     {
-        //These should really be in core, but the @Transformer annotation is not in core
-        muleContext.getRegistry().registerObject("dataHandlerTransformers", new DataHandlerTransformer());
-
         MuleClient client = new MuleClient(muleContext);
         MuleMessage message = client.send("vm://attachmentWithType", muleMessage);
         assertNotNull("return message from MuleClient.send() should not be null", message);
@@ -98,6 +115,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals("fooValue", message.getPayload());
     }
 
+    @Test
     public void testSingleAttachmentOptional() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -106,6 +124,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals("faz not set", message.getPayload());
     }
 
+    @Test
     public void testSingleAttachmentWithTypeNoMatchingTransform() throws Exception
     {
         //TODO this test still works because
@@ -116,6 +135,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals("fooValue", message.getPayload());
     }
 
+    @Test
     public void testMapAttachments() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -128,19 +148,20 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals("barValue", result.get("bar").getContent());
         assertNull(result.get("baz"));
     }
-    
+
+    @Test
     public void testMapAttachmentsMissing() throws Exception
     {
-        //clear attachments
+        // clear attachments
         muleMessage = createMessage(null, new HashMap<String, DataHandler>());
-
-        MuleClient client = new MuleClient(muleContext);
-        MuleMessage message = client.send("vm://attachments", muleMessage);
-        assertNotNull("return message from MuleClient.send() should not be null", message);
+        MuleMessage message = muleContext.getClient().send("vm://attachments", muleMessage);
+        assertNotNull(message);
         assertNotNull(message.getExceptionPayload());
-        assertTrue(message.getExceptionPayload().getRootException() instanceof RequiredValueException);
+        assertEquals(RequiredValueException.class,
+            ExceptionUtils.getRootCause(message.getExceptionPayload().getException()).getClass());
     }
 
+    @Test
     public void testMapSingleAttachment() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -154,6 +175,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertNull(result.get("baz"));
     }
 
+    @Test
     public void testMapAttachmentsOptional() throws Exception
     {
         //clear baz attachment
@@ -173,6 +195,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertNull(result.get("baz"));
     }
 
+    @Test
     public void testMapAttachmentsAllOptional() throws Exception
     {
         //clear attachments
@@ -186,15 +209,17 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals(0, result.size());
     }
 
+    @Test
     public void testMapAttachmentsUnmodifiable() throws Exception
     {
-        MuleClient client = new MuleClient(muleContext);
-        MuleMessage message = client.send("vm://attachmentsUnmodifiable", muleMessage);
-        assertNotNull("return message from MuleClient.send() should not be null", message);
-        assertNotNull("Exception should have been thrown", message.getExceptionPayload());
-        assertTrue(message.getExceptionPayload().getRootException() instanceof UnsupportedOperationException);
+        MuleMessage message = muleContext.getClient().send("vm://attachmentsUnmodifiable", muleMessage);
+        assertNotNull(message);
+        assertNotNull(message.getExceptionPayload());
+        assertEquals(UnsupportedOperationException.class,
+            ExceptionUtils.getRootCause(message.getExceptionPayload().getException()).getClass());
     }
 
+    @Test
     public void testMapAttachmentsAll() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -209,13 +234,14 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals("bazValue", result.get("baz").getContent());
     }
 
+    @Test
     public void testMapAttachmentsWildcard() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
         MuleMessage message = client.send("vm://attachmentsWildcard", muleMessage);
         assertNotNull("return message from MuleClient.send() should not be null", message);
         assertTrue("Message payload should be a Map", message.getPayload() instanceof Map);
-        Map<?, ?> result = (Map<?, ?>) message.getPayload(DataTypeFactory.create(Map.class));
+        Map<?, ?> result = message.getPayload(DataTypeFactory.create(Map.class));
         //Will match on ba*
         assertEquals(2, result.size());
         assertNull(result.get("foo"));
@@ -223,6 +249,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertNotNull(result.get("baz"));
     }
 
+    @Test
     public void testMapAttachmentsMultiWildcard() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -238,6 +265,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertNotNull(result.get("baz"));
     }
 
+    @Test
     public void testListAttachments() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -251,6 +279,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertTrue(result.contains("bazValue"));
     }
 
+    @Test
     public void testListAttachmentsWithOptional() throws Exception
     {
         //clear baz attachment
@@ -269,6 +298,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertTrue(result.contains("barValue"));
     }
 
+    @Test
     public void testListAttachmentsWithAllOptional() throws Exception
     {
         //clear attachments
@@ -282,6 +312,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertEquals(0, result.size());
     }
 
+    @Test
     public void testListAttachmentsWithMissing() throws Exception
     {
         //clear bar attachment
@@ -289,13 +320,15 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         attachments.put("foo", new DataHandler(new StringDataSource("fooValue")));
         attachments.put("baz", new DataHandler(new StringDataSource("bazValue")));
         muleMessage = createMessage(null, attachments);
-        MuleClient client = new MuleClient(muleContext);
-        MuleMessage message = client.send("vm://attachmentsListOptional", muleMessage);
-        assertNotNull("return message from MuleClient.send() should not be null", message);
-        assertNotNull(message.getExceptionPayload());
-        assertTrue(message.getExceptionPayload().getRootException() instanceof RequiredValueException);
+        MuleMessage result = muleContext.getClient().send("vm://attachmentsListOptional", muleMessage);
+        assertNotNull(result);
+        assertNotNull(result.getExceptionPayload());
+        assertEquals(RequiredValueException.class,
+            ExceptionUtils.getRootCause(result.getExceptionPayload().getException()).getClass());
+
     }
 
+    @Test
     public void testSingleListAttachment() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -307,15 +340,17 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertTrue(result.contains("fooValue"));
     }
 
+    @Test
     public void testListAttachmentsUnmodifiable() throws Exception
     {
-        MuleClient client = new MuleClient(muleContext);
-        MuleMessage message = client.send("vm://attachmentsListUnmodifiable", muleMessage);
-        assertNotNull("return message from MuleClient.send() should not be null", message);
-        assertNotNull("Exception should have been thrown", message.getExceptionPayload());
-        assertTrue(message.getExceptionPayload().getRootException() instanceof UnsupportedOperationException);
+        MuleMessage result = muleContext.getClient().send("vm://attachmentsListUnmodifiable", muleMessage);
+        assertNotNull(result);
+        assertNotNull(result.getExceptionPayload());
+        assertEquals(UnsupportedOperationException.class,
+            ExceptionUtils.getRootCause(result.getExceptionPayload().getException()).getClass());
     }
 
+    @Test
     public void testListAttachmentsAll() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -330,6 +365,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertTrue(result.contains("bazValue"));
     }
 
+    @Test
     public void testListAttachmentsWilcard() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -345,6 +381,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
 
     }
 
+    @Test
     public void testListAttachmentsMultiWilcard() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -358,7 +395,7 @@ public class InboundAttachmentsAnnotationTestCase extends FunctionalTestCase
         assertTrue(result.contains("barValue"));
         assertTrue(result.contains("bazValue"));
     }
-    
+
     @SuppressWarnings("unchecked")
     private Map<String, DataHandler> getMapPayload(MuleMessage message)
     {
