@@ -1,5 +1,5 @@
 /*
- * $Id: CollectionTransformerTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: CollectionTransformerTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,7 +13,7 @@ import org.mule.api.annotations.ContainsTransformerMethods;
 import org.mule.api.annotations.Transformer;
 import org.mule.api.transformer.DataType;
 import org.mule.config.transformer.AnnotatedTransformerProxy;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 import org.mule.transformer.types.CollectionDataType;
 import org.mule.transformer.types.DataTypeFactory;
 
@@ -23,6 +23,8 @@ import java.util.ArrayList;
 
 import org.junit.Test;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 @ContainsTransformerMethods
 public class CollectionTransformerTestCase extends AbstractMuleTestCase
