@@ -1,5 +1,5 @@
 /*
- * $Id: ThreadingProfile.java 20811 2010-12-21 10:20:20Z dirk.olmes $
+ * $Id: ThreadingProfile.java 21939 2011-05-18 13:32:09Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,10 +18,9 @@ import org.mule.config.ImmutableThreadingProfile;
 import org.mule.config.pool.ThreadPoolFactory;
 
 import java.util.Map;
-
-import edu.emory.mathcs.backport.java.util.concurrent.ExecutorService;
-import edu.emory.mathcs.backport.java.util.concurrent.RejectedExecutionHandler;
-import edu.emory.mathcs.backport.java.util.concurrent.ThreadFactory;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.RejectedExecutionHandler;
+import java.util.concurrent.ThreadFactory;
 
 import org.apache.commons.collections.map.CaseInsensitiveMap;
 
