@@ -1,5 +1,5 @@
 /*
- * $Id: ServerNotification.java 20332 2010-11-24 18:14:09Z aperepel $
+ * $Id: ServerNotification.java 22396 2011-07-12 21:26:04Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -20,8 +20,7 @@ import org.mule.util.ClassUtils;
 
 import java.util.EventObject;
 import java.util.Map;
-
-import edu.emory.mathcs.backport.java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentHashMap;
 
 /**
  * <code>ServerNotification</code> is an event triggered by something happening in
@@ -69,11 +68,9 @@ public abstract class ServerNotification extends EventObject implements MuleCont
 
     protected int action = NULL_ACTION;
 
-    @SuppressWarnings("unchecked")
-    private static Map<Integer, String> actionIdToName = new ConcurrentHashMap();
+    private static Map<Integer, String> actionIdToName = new ConcurrentHashMap<Integer, String>();
 
-    @SuppressWarnings("unchecked")
-    private static Map<String, Integer> actionNameToId = new ConcurrentHashMap();
+    private static Map<String, Integer> actionNameToId = new ConcurrentHashMap<String, Integer>();
 
     /**
      * The resourceIdentifier is used when firing inbound server notifications such
@@ -99,6 +96,7 @@ public abstract class ServerNotification extends EventObject implements MuleCont
         timestamp = System.currentTimeMillis();
     }
 
+    @Override
     public void setMuleContext(MuleContext context)
     {
         muleContext = context;
@@ -110,7 +108,7 @@ public abstract class ServerNotification extends EventObject implements MuleCont
         MuleConfiguration conf = context.getConfiguration();
         return String.format("%s.%s.%s",
                              conf.getDomainId(),
-                             conf.getClusterId(),
+                             context.getClusterId(),
                              conf.getId());
     }
 
@@ -208,7 +206,7 @@ public abstract class ServerNotification extends EventObject implements MuleCont
         String lowerCaseName = action.toLowerCase();
         if (actionNameToId.containsKey(lowerCaseName))
         {
-            return ((Integer) actionNameToId.get(lowerCaseName)).intValue();
+            return actionNameToId.get(lowerCaseName).intValue();
         }
         else
         {
