@@ -1,5 +1,5 @@
 /*
- * $Id: InvocationResult.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: InvocationResult.java 20694 2010-12-14 07:22:38Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,11 +18,14 @@ import java.lang.reflect.Method;
  */
 public class InvocationResult
 {
-    public static enum State {
+    public static enum State
+    {
         /** the resolver performing the invocation knows that it cannot attempt to make the invocation */
         NOT_SUPPORTED,
+
         /** the invocation was successful */
         SUCCESSFUL,
+
         /** The invocation was attempted but failed */
         FAILED
     }
