@@ -1,5 +1,5 @@
 /*
- * $Id: Service.java 20814 2010-12-21 12:24:23Z dirk.olmes $
+ * $Id: Service.java 22048 2011-05-31 14:39:03Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,7 +13,7 @@ package org.mule.api.service;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
-import org.mule.api.NamedObject;
+import org.mule.api.NameableObject;
 import org.mule.api.component.Component;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.exception.MessagingExceptionHandler;
@@ -33,7 +33,7 @@ import java.io.Serializable;
  * is responsible for managing the interaction of events to and from the service as
  * well as managing pooled resources.
  */
-public interface Service extends Serializable, FlowConstruct, Lifecycle, NamedObject
+public interface Service extends Serializable, FlowConstruct, Lifecycle, NameableObject
 {
     /**
      * Makes an asynchronous event call to the service.
