@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractInterceptorTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: AbstractInterceptorTestCase.java 22421 2011-07-15 05:05:06Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,14 +10,21 @@
 
 package org.mule.config.spring;
 
-import org.mule.tck.FunctionalTestCase;
 import org.mule.api.MuleException;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 
-public abstract class AbstractInterceptorTestCase extends FunctionalTestCase
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
+public abstract class AbstractInterceptorTestCase extends AbstractServiceAndFlowTestCase
 {
-
     public static final String MESSAGE = "boo";
 
+    public AbstractInterceptorTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
     public void assertMessageIntercepted() throws MuleException, InterruptedException
     {
         FunctionalTestAdvice advice = (FunctionalTestAdvice) muleContext.getRegistry().lookupObject("advice");
@@ -25,5 +32,4 @@ public abstract class AbstractInterceptorTestCase extends FunctionalTestCase
         String message = advice.getMessage(RECEIVE_TIMEOUT);
         assertEquals("Bad message", MESSAGE, message);
     }
-
 }
