@@ -1,5 +1,5 @@
 /*
- * $Id: FunctionalTestAdvice.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: FunctionalTestAdvice.java 21939 2011-05-18 13:32:09Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,13 +10,13 @@
 
 package org.mule.config.spring;
 
-import org.mule.util.concurrent.Latch;
 import org.mule.api.MuleEventContext;
+import org.mule.util.concurrent.Latch;
 
 import java.lang.reflect.Method;
+import java.util.concurrent.TimeUnit;
 
 import org.springframework.aop.MethodBeforeAdvice;
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
 
 public class FunctionalTestAdvice implements MethodBeforeAdvice
 {
