@@ -1,5 +1,5 @@
 /*
- * $Id: AsyncMessageProcessorsFactoryBean.java 21929 2011-05-17 14:26:50Z dfeist $
+ * $Id: AsyncMessageProcessorsFactoryBean.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,40 +10,40 @@
 
 package org.mule.config.spring.factories;
 
+import org.mule.api.AnnotatedObject;
 import org.mule.api.MuleContext;
-import org.mule.api.NamedObject;
-import org.mule.api.config.MuleConfiguration;
-import org.mule.api.config.ThreadingProfile;
+import org.mule.api.NameableObject;
 import org.mule.api.context.MuleContextAware;
 import org.mule.api.processor.MessageProcessor;
 import org.mule.api.processor.MessageProcessorBuilder;
+import org.mule.api.processor.ProcessingStrategy;
 import org.mule.processor.AsyncDelegateMessageProcessor;
 import org.mule.processor.chain.DefaultMessageProcessorChainBuilder;
-import org.mule.util.concurrent.ThreadNameHelper;
 
+import java.util.Collections;
 import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+
+import javax.xml.namespace.QName;
 
 import org.springframework.beans.factory.FactoryBean;
 
-public class AsyncMessageProcessorsFactoryBean implements FactoryBean, MuleContextAware, NamedObject
+public class AsyncMessageProcessorsFactoryBean implements FactoryBean, MuleContextAware, NameableObject, AnnotatedObject
 {
 
     protected MuleContext muleContext;
 
     protected List messageProcessors;
-    protected ThreadingProfile threadingProfile;
+    protected ProcessingStrategy processingStrategy;
     protected String name;
+    private final Map<QName, Object> annotations = new ConcurrentHashMap<QName, Object>();
 
     public Class getObjectType()
     {
         return MessageProcessor.class;
     }
 
-    public void setThreadingProfile(ThreadingProfile threadingProfile)
-    {
-        this.threadingProfile = threadingProfile;
-    }
-
     public void setMessageProcessors(List messageProcessors)
     {
         this.messageProcessors = messageProcessors;
@@ -51,19 +51,9 @@ public class AsyncMessageProcessorsFactoryBean implements FactoryBean, MuleConte
 
     public Object getObject() throws Exception
     {
-        if (threadingProfile == null)
-        {
-            threadingProfile = muleContext.getDefaultThreadingProfile();
-        }
-
         DefaultMessageProcessorChainBuilder builder = new DefaultMessageProcessorChainBuilder();
         builder.setName("'async' child chain");
-        final MuleConfiguration config = muleContext.getConfiguration();
-        final String threadPrefix = ThreadNameHelper.asyncProcessor(muleContext, name);
 
-        AsyncDelegateMessageProcessor asyncProcessor = new AsyncDelegateMessageProcessor(threadingProfile,
-                                                                                                 threadPrefix,
-                                                                                                 config.getShutdownTimeout());
         for (Object processor : messageProcessors)
         {
             if (processor instanceof MessageProcessor)
@@ -80,8 +70,10 @@ public class AsyncMessageProcessorsFactoryBean implements FactoryBean, MuleConte
                     "MessageProcessorBuilder should only have MessageProcessor's or MessageProcessorBuilder's configured");
             }
         }
-        asyncProcessor.setDelegate(builder.build());
-        return  asyncProcessor;
+        AsyncDelegateMessageProcessor delegate = new AsyncDelegateMessageProcessor(builder.build(),
+            processingStrategy, name);
+        delegate.setAnnotations(getAnnotations());
+        return delegate;
     }
 
     public boolean isSingleton()
@@ -104,4 +96,24 @@ public class AsyncMessageProcessorsFactoryBean implements FactoryBean, MuleConte
         this.name = name;
     }
 
+    public void setProcessingStrategy(ProcessingStrategy processingStrategy)
+    {
+        this.processingStrategy = processingStrategy;
+    }
+
+    public final Object getAnnotation(QName name)
+    {
+        return annotations.get(name);
+    }
+
+    public final Map<QName, Object> getAnnotations()
+    {
+        return Collections.unmodifiableMap(annotations);
+    }
+
+    public synchronized final void setAnnotations(Map<QName, Object> newAnnotations)
+    {
+        annotations.clear();
+        annotations.putAll(newAnnotations);
+    }
 }
