@@ -1,5 +1,5 @@
 /*
- * $Id: ParentSimpleTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: ParentSimpleTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,14 +13,18 @@ package org.mule.config.spring.parsers;
 import org.mule.config.spring.parsers.beans.ChildBean;
 import org.mule.config.spring.parsers.beans.OrphanBean;
 
+import org.junit.Test;
+
 public class ParentSimpleTestCase extends AbstractNamespaceTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/config/spring/parsers/parent-simple-test.xml";
     }
 
+    @Test
     public void testParent3()
     {
         OrphanBean orphan3 = (OrphanBean) assertBeanExists("orphan3", OrphanBean.class);
