@@ -1,5 +1,5 @@
 /*
- * $Id: ThirdPartyTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: ThirdPartyTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,16 +11,22 @@
 package org.mule.config.spring.parsers;
 
 import org.mule.config.spring.parsers.beans.ThirdPartyContainer;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertNotNull;
 
 public class ThirdPartyTestCase extends FunctionalTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/config/spring/parsers/third-party-test.xml";
     }
 
+    @Test
     public void testContainer()
     {
         ThirdPartyContainer container = (ThirdPartyContainer) muleContext.getRegistry().lookupObject("container");
