@@ -1,5 +1,5 @@
 /*
- * $Id: ServiceDefinitionParser.java 13129 2008-10-24 15:31:16Z aperepel $
+ * $Id: FlowDefinitionParser.java 22557 2011-07-25 22:48:27Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,19 +12,21 @@ package org.mule.config.spring.parsers.specific;
 
 import org.mule.api.config.MuleProperties;
 import org.mule.config.spring.parsers.generic.OrphanDefinitionParser;
-import org.mule.construct.SimpleFlowConstruct;
+import org.mule.config.spring.util.ProcessingStrategyUtils;
+import org.mule.construct.Flow;
+
 import org.springframework.beans.factory.support.BeanDefinitionBuilder;
 import org.springframework.beans.factory.xml.ParserContext;
 import org.w3c.dom.Element;
 
 public class FlowDefinitionParser extends OrphanDefinitionParser
 {
-
     public FlowDefinitionParser()
     {
-        super(SimpleFlowConstruct.class, true);
+        super(Flow.class, true);
         addIgnored("abstract");
         addIgnored("name");
+        addIgnored("processingStrategy");
     }
 
     @java.lang.Override
@@ -32,7 +34,8 @@ public class FlowDefinitionParser extends OrphanDefinitionParser
     {
         builder.addConstructorArgValue(element.getAttribute(ATTRIBUTE_NAME));
         builder.addConstructorArgReference(MuleProperties.OBJECT_MULE_CONTEXT);
+        ProcessingStrategyUtils.configureProcessingStrategy(element, builder,
+            ProcessingStrategyUtils.QUEUED_ASYNC_PROCESSING_STRATEGY);
         super.doParse(element, parserContext, builder);
     }
-
 }
