@@ -1,5 +1,5 @@
 /*
- * $Id: EndpointMessageNotification.java 20339 2010-11-24 18:32:35Z aperepel $
+ * $Id: EndpointMessageNotification.java 22609 2011-08-08 17:58:59Z julien.eluard $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,6 +11,7 @@
 package org.mule.context.notification;
 
 import org.mule.api.MuleMessage;
+import org.mule.api.construct.FlowConstruct;
 import org.mule.api.context.notification.ServerNotification;
 import org.mule.api.endpoint.ImmutableEndpoint;
 
@@ -39,7 +40,8 @@ public class EndpointMessageNotification extends ServerNotification
     public static final int MESSAGE_REQUESTED = MESSAGE_EVENT_ACTION_START_RANGE + 4;
     public static final int MESSAGE_RESPONSE = MESSAGE_EVENT_ACTION_START_RANGE + 5;
 
-    static {
+    static
+    {
         registerAction("received", MESSAGE_RECEIVED);
         registerAction("dispatched", MESSAGE_DISPATCHED);
         registerAction("sent", MESSAGE_SENT);
@@ -48,15 +50,19 @@ public class EndpointMessageNotification extends ServerNotification
     }
 
     private String endpoint;
+    private ImmutableEndpoint immutableEndpoint;
+    private FlowConstruct flowConstruct;
 
     public EndpointMessageNotification(MuleMessage resource,
                                ImmutableEndpoint endpoint,
-                               String identifier,
+                               FlowConstruct flowConstruct,
                                int action)
     {
         super(cloneMessage(resource), action);
-        resourceIdentifier = identifier;
+        resourceIdentifier = flowConstruct != null ? flowConstruct.getName() : null;
         this.endpoint = endpoint.getEndpointURI().toString();
+        this.immutableEndpoint = endpoint;
+        this.flowConstruct = flowConstruct;
     }
 
 
@@ -86,6 +92,17 @@ public class EndpointMessageNotification extends ServerNotification
         return endpoint;
     }
 
+    public ImmutableEndpoint getImmutableEndpoint()
+    {
+        return immutableEndpoint;
+    }
+
+    public FlowConstruct getFlowConstruct()
+    {
+        return flowConstruct;
+    }
+
+    @Override
     public String getType()
     {
         return TYPE_TRACE;
@@ -96,5 +113,4 @@ public class EndpointMessageNotification extends ServerNotification
     {
         return (MuleMessage) super.getSource();
     }
-
 }
