@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractEndpoint.java 21251 2011-02-11 00:23:49Z dandiep $
+ * $Id: AbstractEndpoint.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,6 +11,7 @@
 package org.mule.endpoint;
 
 import org.mule.MessageExchangePattern;
+import org.mule.api.AnnotatedObject;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
 import org.mule.api.construct.FlowConstruct;
@@ -27,19 +28,22 @@ import org.mule.api.security.SecurityFilter;
 import org.mule.api.transaction.TransactionConfig;
 import org.mule.api.transformer.Transformer;
 import org.mule.api.transport.Connector;
+import org.mule.processor.AbstractRedeliveryPolicy;
 import org.mule.processor.SecurityFilterMessageProcessor;
 import org.mule.routing.MessageFilter;
 import org.mule.util.ClassUtils;
 
 import java.net.URI;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import edu.emory.mathcs.backport.java.util.Collections;
+import javax.xml.namespace.QName;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -48,7 +52,7 @@ import org.apache.commons.logging.LogFactory;
  * <code>ImmutableMuleEndpoint</code> describes a Provider in the Mule Server. A
  * endpoint is a grouping of an endpoint, an endpointUri and a transformer.
  */
-public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
+public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable, AnnotatedObject
 {
 
     private static final long serialVersionUID = -1650380871293160973L;
@@ -126,7 +130,10 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
 
     private final String endpointMimeType;
 
+    private AbstractRedeliveryPolicy redeliveryPolicy;
+
     private boolean disableTransportTransformer = false;
+    private final Map<QName, Object> annotations = new ConcurrentHashMap<QName, Object>();
 
     public AbstractEndpoint(Connector connector,
                             EndpointURI endpointUri,
@@ -141,6 +148,7 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
                             String endpointBuilderName,
                             MuleContext muleContext,
                             RetryPolicyTemplate retryPolicyTemplate,
+                            AbstractRedeliveryPolicy redeliveryPolicy,
                             EndpointMessageProcessorChainFactory messageProcessorsFactory,
                             List <MessageProcessor> messageProcessors,
                             List <MessageProcessor> responseMessageProcessors,
@@ -162,24 +170,10 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
         this.endpointBuilderName = endpointBuilderName;
         this.muleContext = muleContext;
         this.retryPolicyTemplate = retryPolicyTemplate;
+        this.redeliveryPolicy = redeliveryPolicy;
         this.endpointMimeType = endpointMimeType;
         this.disableTransportTransformer = disableTransportTransformer;
-
-        if (transactionConfig != null && transactionConfig.getFactory() != null &&
-            transactionConfig.getAction() != TransactionConfig.ACTION_NONE &&
-            transactionConfig.getAction() != TransactionConfig.ACTION_NEVER)
-        {
-            if (logger.isDebugEnabled())
-            {
-                logger.debug("Endpoint has a transaction configuration. Defaulting to REQUEST_RESPONSE. Endpoint is: " + toString());
-            }
-            this.messageExchangePattern = MessageExchangePattern.REQUEST_RESPONSE;
-        }
-        else
-        {
-            this.messageExchangePattern = messageExchangePattern;
-        }
-
+        this.messageExchangePattern = messageExchangePattern;
         this.messageProcessorsFactory = messageProcessorsFactory;
         if (messageProcessors == null)
         {
@@ -487,6 +481,11 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
         return retryPolicyTemplate;
     }
 
+    public AbstractRedeliveryPolicy getRedeliveryPolicy()
+    {
+        return redeliveryPolicy;
+    }
+
     public String getEndpointBuilderName()
     {
         return endpointBuilderName;
@@ -505,7 +504,9 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
     public void dispose()
     {
         this.muleContext = null;
-        this.messageProcessors.clear();
+        // this.messageProcessors.clear();
+        // Don't clear this, since it changes the hash code, which can foul up shutdown processing
+        // when objects have been keyed by endpoint, e.g. dispatchers
         this.messageProcessorChain = null;
     }
 
@@ -518,5 +519,21 @@ public abstract class AbstractEndpoint implements ImmutableEndpoint, Disposable
         return messageProcessorChain;
     }
 
+    public final Object getAnnotation(QName name)
+    {
+        return annotations.get(name);
+    }
+
+    public final Map<QName, Object> getAnnotations()
+    {
+        return Collections.unmodifiableMap(annotations);
+    }
+
+    public synchronized final void setAnnotations(Map<QName, Object> newAnnotations)
+    {
+        annotations.clear();
+        annotations.putAll(newAnnotations);
+    }
+
     abstract protected MessageProcessor createMessageProcessorChain(FlowConstruct flowContruct) throws MuleException;
 }
