@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultOutboundEndpoint.java 21695 2011-04-18 20:25:06Z pablo.kraan $
+ * $Id: DefaultOutboundEndpoint.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,7 +10,6 @@
 
 package org.mule.endpoint;
 
-import org.mule.DefaultMuleEvent;
 import org.mule.MessageExchangePattern;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
@@ -27,6 +26,7 @@ import org.mule.api.processor.MessageProcessor;
 import org.mule.api.retry.RetryPolicyTemplate;
 import org.mule.api.transaction.TransactionConfig;
 import org.mule.api.transport.Connector;
+import org.mule.processor.AbstractRedeliveryPolicy;
 import org.mule.transport.AbstractConnector;
 import org.mule.util.StringUtils;
 
@@ -54,6 +54,7 @@ public class DefaultOutboundEndpoint extends AbstractEndpoint implements Outboun
                                    String endpointBuilderName,
                                    MuleContext muleContext,
                                    RetryPolicyTemplate retryPolicyTemplate,
+                                   AbstractRedeliveryPolicy redeliveryPolicy,
                                    String responsePropertiesList,
                                    EndpointMessageProcessorChainFactory messageProcessorsFactory,
                                    List <MessageProcessor> messageProcessors,
@@ -63,9 +64,13 @@ public class DefaultOutboundEndpoint extends AbstractEndpoint implements Outboun
     {
         super(connector, endpointUri, name, properties, transactionConfig, 
                 deleteUnacceptedMessage, messageExchangePattern, responseTimeout, initialState,
-                endpointEncoding, endpointBuilderName, muleContext, retryPolicyTemplate, 
+                endpointEncoding, endpointBuilderName, muleContext, retryPolicyTemplate, null,
                 messageProcessorsFactory, messageProcessors, responseMessageProcessors, disableTransportTransformer, endpointMimeType);
 
+        if (redeliveryPolicy != null)
+        {
+            logger.warn("Ignoring redelivery policy set on outbound endpoint " + endpointUri);
+        }
         responseProperties = new ArrayList<String>();
         // Propagate the Correlation-related properties from the previous message by default (see EE-1613).
         responseProperties.add(MuleProperties.MULE_CORRELATION_ID_PROPERTY);
@@ -87,12 +92,6 @@ public class DefaultOutboundEndpoint extends AbstractEndpoint implements Outboun
 
     public MuleEvent process(MuleEvent event) throws MuleException
     {
-        // Update event endpoint for outbound endpoint
-        if ((event.getEndpoint() == null || !event.getEndpoint().equals(this)))
-        {
-            event = new DefaultMuleEvent(event.getMessage(), this, event.getSession(), null, event.getProcessingTime());
-        }
-
         return getMessageProcessorChain(event.getFlowConstruct()).process(event);
     }
 
