@@ -1,5 +1,5 @@
 /*
- * $Id: DynamicURIInboundEndpoint.java 21286 2011-02-15 20:09:25Z dzapata $
+ * $Id: DynamicURIInboundEndpoint.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -27,6 +27,7 @@ import org.mule.api.transaction.TransactionConfig;
 import org.mule.api.transformer.Transformer;
 import org.mule.api.transport.Connector;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.processor.AbstractRedeliveryPolicy;
 import org.mule.transport.ConnectException;
 
 import java.util.List;
@@ -96,6 +97,12 @@ public class DynamicURIInboundEndpoint implements InboundEndpoint
         return endpoint.getRetryPolicyTemplate();
     }
 
+    @Override
+    public AbstractRedeliveryPolicy getRedeliveryPolicy()
+    {
+        return endpoint.getRedeliveryPolicy();
+    }
+
     public Connector getConnector()
     {
         return endpoint.getConnector();
@@ -310,4 +317,5 @@ public class DynamicURIInboundEndpoint implements InboundEndpoint
     {
         this.listener = listener;
     }
+    
 }
