@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: OutboundEndpointPropertyMessageProcessorTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,21 +13,25 @@ package org.mule.endpoint.outbound;
 import org.mule.RequestContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.config.MuleProperties;
-import org.mule.api.endpoint.EndpointException;
 import org.mule.api.endpoint.OutboundEndpoint;
-import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.processor.MessageProcessor;
 import org.mule.endpoint.AbstractMessageProcessorTestCase;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertSame;
+
 public class OutboundEndpointPropertyMessageProcessorTestCase extends AbstractMessageProcessorTestCase
 {
 
-    public void testProcess() throws InitialisationException, EndpointException, Exception
+    @Test
+    public void testProcess() throws Exception
     {
-        MessageProcessor mp = new OutboundEndpointPropertyMessageProcessor();
         OutboundEndpoint endpoint = createTestOutboundEndpoint(null, null);
+        MessageProcessor mp = new OutboundEndpointPropertyMessageProcessor(endpoint);
 
-        MuleEvent event = mp.process(createTestOutboundEvent(endpoint));
+        MuleEvent event = mp.process(createTestOutboundEvent());
 
         assertEquals(endpoint.getEndpointURI().getUri().toString(),
                      event.getMessage().getOutboundProperty(MuleProperties.MULE_ENDPOINT_PROPERTY));
