@@ -1,5 +1,5 @@
 /*
- * $Id: CustomFilterMule2437TestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: CustomFilterMule2437TestCase.java 22552 2011-07-25 07:18:19Z claude.mamo $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,26 +10,46 @@
 
 package org.mule.issues;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+
 import org.mule.DefaultMuleMessage;
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 
-public class CustomFilterMule2437TestCase extends FunctionalTestCase
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+public class CustomFilterMule2437TestCase extends AbstractServiceAndFlowTestCase
 {
 
     private static final long TIMEOUT = 3000L;
 
-    protected String getConfigResources()
+    public CustomFilterMule2437TestCase(ConfigVariant variant, String configResources)
     {
-        return "issues/custom-filter-mule-2437-test.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "issues/custom-filter-mule-2437-test-service.xml"},
+            {ConfigVariant.FLOW, "issues/custom-filter-mule-2437-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testVowels() throws Exception
     {
         doTest("aei", "vm://vowels");
     }
 
+    @Test
     public void testConsonants() throws Exception
     {
         doTest("zyx", "vm://consonants");
