@@ -1,5 +1,5 @@
 /*
- * $Id: SedaService.java 21229 2011-02-10 02:41:30Z dfeist $
+ * $Id: SedaService.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -23,6 +23,7 @@ import org.mule.config.i18n.MessageFactory;
 import org.mule.interceptor.ProcessingTimeInterceptor;
 import org.mule.lifecycle.processor.ProcessIfStartedWaitIfSyncPausedMessageProcessor;
 import org.mule.management.stats.ServiceStatistics;
+import org.mule.processor.LaxSedaStageInterceptingMessageProcessor;
 import org.mule.processor.SedaStageInterceptingMessageProcessor;
 import org.mule.service.AbstractService;
 import org.mule.service.processor.ServiceInternalMessageProcessor;
@@ -31,6 +32,7 @@ import org.mule.service.processor.ServiceOutboundMessageProcessor;
 import org.mule.service.processor.ServiceOutboundStatisticsMessageProcessor;
 import org.mule.service.processor.ServiceSetEventRequestContextMessageProcessor;
 import org.mule.service.processor.ServiceStatisticsMessageProcessor;
+import org.mule.util.concurrent.ThreadNameHelper;
 
 /**
  * A Seda service runs inside a Seda Model and is responsible for managing a Seda
@@ -82,8 +84,9 @@ public class SedaService extends AbstractService
         builder.chain(new ServiceSetEventRequestContextMessageProcessor());
         if (getThreadingProfile().isDoThreading())
         {
-            sedaStage = new SedaStageInterceptingMessageProcessor(getName(), queueProfile, queueTimeout,
-                threadingProfile, stats, muleContext);
+            sedaStage = new LaxSedaStageInterceptingMessageProcessor(ThreadNameHelper.sedaService(
+                muleContext, getName()), getName(), queueProfile, queueTimeout, threadingProfile, stats,
+                muleContext);
             builder.chain(sedaStage);
         }
         builder.chain(new ServiceInternalMessageProcessor(this));
