@@ -1,5 +1,5 @@
 /*
- * $Id: SedaServiceTestCase.java 20534 2010-12-08 22:01:21Z dzapata $
+ * $Id: SedaServiceTestCase.java 22870 2011-09-05 20:41:52Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,13 @@
 
 package org.mule.model.seda;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.when;
+
 import org.mule.MessageExchangePattern;
 import org.mule.api.MuleEventContext;
 import org.mule.api.config.MuleProperties;
@@ -17,6 +24,7 @@ import org.mule.api.config.ThreadingProfile;
 import org.mule.api.lifecycle.Callable;
 import org.mule.api.registry.RegistrationException;
 import org.mule.api.service.Service;
+import org.mule.api.store.ListableObjectStore;
 import org.mule.component.DefaultJavaComponent;
 import org.mule.component.SimpleCallableJavaComponent;
 import org.mule.config.ChainedThreadingProfile;
@@ -27,15 +35,16 @@ import org.mule.tck.MuleTestUtils;
 import org.mule.util.concurrent.Latch;
 import org.mule.util.queue.QueueManager;
 
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
+import java.io.Serializable;
+import java.util.concurrent.TimeUnit;
+
 import junit.framework.AssertionFailedError;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.when;
+
+import org.junit.Test;
 
 public class SedaServiceTestCase extends AbstractServiceTestCase
 {
     private SedaService service;
-    private Thread mainThread = Thread.currentThread();
 
     public SedaServiceTestCase()
     {
@@ -65,9 +74,9 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
      * the queue that is used. 2) The queue used by the SedaService has the correct
      * name.
      */
+    @Test
     public void testQueueConfiguration() throws Exception
     {
-        boolean persistent = true;
         int capacity = 345;
 
         QueueManager queueManager = muleContext.getQueueManager();
@@ -80,7 +89,9 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         muleContext.getRegistry().registerObject(MuleProperties.OBJECT_QUEUE_MANAGER,
             mockTransactionalQueueManager);
 
-        service.setQueueProfile(new QueueProfile(capacity, persistent));
+        ListableObjectStore<Serializable> objectStore =
+            muleContext.getRegistry().lookupObject(MuleProperties.OBJECT_STORE_DEFAULT_PERSISTENT_NAME);
+        service.setQueueProfile(new QueueProfile(capacity, objectStore));
 
         try
         {
@@ -99,6 +110,7 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         }
     }
 
+    @Test
     public void testSedaModelEventTimeoutDefault() throws Exception
     {
         service.initialise();
@@ -109,26 +121,23 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
 
     /**
      * SEE MULE-3684
-     * 
-     * @throws Exception
      */
+    @Test
     public void testDispatchToPausedService() throws Exception
     {
         service.initialise();
         service.start();
         service.pause();
-        service.dispatchEvent(MuleTestUtils.getTestEvent("test", 
+        service.process(MuleTestUtils.getTestEvent("test",
             getTestInboundEndpoint(MessageExchangePattern.ONE_WAY), muleContext));
 
         // This test will timeout and fail if dispatch() blocks
-
     }
 
     /**
      * SEE MULE-3974
-     * 
-     * @throws Exception
      */
+    @Test
     public void testMaxActiveThreadsEqualsOneWhenExhaustedActionWait() throws Exception
     {
         final Latch latch = new Latch();
@@ -140,7 +149,7 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         service.setThreadingProfile(threadingProfile);
         final SimpleCallableJavaComponent component = new SimpleCallableJavaComponent(new Callable()
         {
-
+            @Override
             public Object onCall(MuleEventContext eventContext) throws Exception
             {
                 latch.countDown();
@@ -151,19 +160,16 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         service.setComponent(component);
         muleContext.getRegistry().registerService(service);
 
-        service.dispatchEvent(MuleTestUtils.getTestInboundEvent("test", service, muleContext));
-
+        service.process(MuleTestUtils.getTestEvent("test", service, muleContext));
         assertTrue(latch.await(200, TimeUnit.MILLISECONDS));
 
         // This test will fail with RejectedExcecutionException if dispatch() blocks
-
     }
 
     /**
      * SEE MULE-3975
-     * 
-     * @throws Exception
      */
+    @Test
     public void testDoThreadingFalse() throws Exception
     {
         final Latch latch = new Latch();
@@ -173,8 +179,11 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         ChainedThreadingProfile threadingProfile = (ChainedThreadingProfile) muleContext.getDefaultServiceThreadingProfile();
         threadingProfile.setDoThreading(false);
         service.setThreadingProfile(threadingProfile);
+        final Thread mainThread = Thread.currentThread();
+
         final SimpleCallableJavaComponent component = new SimpleCallableJavaComponent(new Callable()
         {
+            @Override
             public Object onCall(MuleEventContext eventContext) throws Exception
             {
                 assertEquals(mainThread, Thread.currentThread());
@@ -186,18 +195,16 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         service.setComponent(component);
         muleContext.getRegistry().registerService(service);
 
-        service.dispatchEvent(MuleTestUtils.getTestEvent("test", 
+        service.process(MuleTestUtils.getTestEvent("test",
             getTestInboundEndpoint(MessageExchangePattern.ONE_WAY), muleContext));
 
         assertTrue(latch.await(200, TimeUnit.MILLISECONDS));
-
     }
 
     /**
      * SEE MULE-3975
-     * 
-     * @throws Exception
      */
+    @Test
     public void testDoThreadingTrue() throws Exception
     {
         final Latch latch = new Latch();
@@ -209,9 +216,11 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         service.setThreadingProfile(threadingProfile);
         final SimpleCallableJavaComponent component = new SimpleCallableJavaComponent(new Callable()
         {
+            @Override
             public Object onCall(MuleEventContext eventContext) throws Exception
             {
-                assertTrue(Thread.currentThread().getName().startsWith("seda." + serviceName));
+                System.out.println(Thread.currentThread().getName());
+                assertTrue(Thread.currentThread().getName().startsWith(serviceName));
                 latch.countDown();
                 return null;
             }
@@ -220,11 +229,9 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         service.setComponent(component);
         muleContext.getRegistry().registerService(service);
 
-        service.dispatchEvent(MuleTestUtils.getTestEvent("test", 
+        service.process(MuleTestUtils.getTestEvent("test",
             getTestInboundEndpoint(MessageExchangePattern.ONE_WAY), muleContext));
 
         assertTrue(latch.await(200, TimeUnit.MILLISECONDS));
-
     }
-
 }
