@@ -1,5 +1,5 @@
 /*
- * $Id: FeedReceiver.java 20053 2010-11-02 21:44:36Z dzapata $
+ * $Id: FeedReceiver.java 20321 2010-11-24 15:21:24Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,7 +18,7 @@ import org.apache.abdera.model.Feed;
 public class FeedReceiver
 {
 
-    public static AtomicInteger receivedEntries = new AtomicInteger(0);
+    private final AtomicInteger receivedEntries = new AtomicInteger(0);
 
     public void processFeed(@Payload Feed feed) throws Exception
     {
@@ -26,4 +26,14 @@ public class FeedReceiver
         System.out.println("Received " + feed.getEntries().size() + " events");
         receivedEntries.set(feed.getEntries().size());
     }
+
+    public int getCount()
+    {
+        return receivedEntries.get();
+    }
+
+    public AtomicInteger getReceivedEntries()
+    {
+        return receivedEntries;
+    }
 }
