@@ -1,5 +1,5 @@
 /*
- * $Id: CxfComponentExceptionStrategyTestCase.java 21151 2011-01-31 21:53:23Z dzapata $
+ * $Id: CxfComponentExceptionStrategyTestCase.java 22728 2011-08-24 15:51:41Z pablo.kraan $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -15,13 +15,44 @@ import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.module.client.MuleClient;
 import org.mule.module.cxf.testmodels.CustomFault;
 import org.mule.module.cxf.testmodels.CxfEnabledFaultMessage;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
+
+import java.util.Arrays;
+import java.util.Collection;
 
-import org.apache.cxf.binding.soap.SoapFault;
 import org.apache.cxf.interceptor.Fault;
+import org.junit.Ignore;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 
-public class CxfComponentExceptionStrategyTestCase extends DynamicPortTestCase
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+public class CxfComponentExceptionStrategyTestCase extends AbstractServiceAndFlowTestCase
 {
+
+    public CxfComponentExceptionStrategyTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");   
+
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "exception-strategy-conf-service.xml"},
+            {ConfigVariant.FLOW, "exception-strategy-conf-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testDefaultComponentExceptionStrategy() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -33,16 +64,13 @@ public class CxfComponentExceptionStrategyTestCase extends DynamicPortTestCase
         }
         catch (MessagingException e)
         {
-            assertTrue(e.getCause().getCause() instanceof SoapFault);
+            assertTrue(e.getCause().getCause() instanceof CxfEnabledFaultMessage);
         }
     }
 
-    /**
-     * This doesn't work because of a bug in the CXF client code :-(
-     * 
-     * @throws Exception
-     */
-    public void xtestHandledException() throws Exception
+    @Test
+    @Ignore("This doesn't work because of a bug in the CXF client code :-(")
+    public void testHandledException() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
 
@@ -62,6 +90,7 @@ public class CxfComponentExceptionStrategyTestCase extends DynamicPortTestCase
         }
     }
 
+    @Test
     public void testUnhandledException() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -77,14 +106,4 @@ public class CxfComponentExceptionStrategyTestCase extends DynamicPortTestCase
         }
     }
 
-    protected String getConfigResources()
-    {
-        return "exception-strategy-conf.xml";
-    }
-
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
 }
