@@ -1,5 +1,5 @@
 /*
- * $Id: CxfConfiguration.java 20088 2010-11-05 16:51:41Z aperepel $
+ * $Id: CxfConfiguration.java 21217 2011-02-09 19:57:31Z dandiep $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,6 +17,9 @@ import org.mule.api.lifecycle.Disposable;
 import org.mule.api.lifecycle.Initialisable;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.config.spring.SpringRegistry;
+import org.mule.module.cxf.support.MuleHeadersInInterceptor;
+import org.mule.module.cxf.support.MuleHeadersOutInterceptor;
+import org.mule.module.cxf.support.MuleProtocolHeadersOutInterceptor;
 import org.mule.module.cxf.transport.MuleUniversalTransport;
 
 import java.lang.reflect.Field;
@@ -49,8 +52,9 @@ public class CxfConfiguration implements Initialisable, Disposable, MuleContextA
     // The CXF Bus object
     private Bus bus;
     private String configurationLocation;
-    private boolean initializeStaticBusInstance = true;
+    private boolean initializeStaticBusInstance;
     private MuleContext muleContext;
+    private boolean enableMuleSoapHeaders = true;
     
     public void initialise() throws InitialisationException
     {
@@ -78,6 +82,9 @@ public class CxfConfiguration implements Initialisable, Disposable, MuleContextA
         dfm.registerDestinationFactory("http://cxf.apache.org/transports/http/configuration", transport);
         dfm.registerDestinationFactory("http://schemas.xmlsoap.org/wsdl/http/", transport);
         dfm.registerDestinationFactory("http://www.w3.org/2003/05/soap/bindings/HTTP/", transport);
+        dfm.registerDestinationFactory("http://cxf.apache.org/transports/jms", transport);
+        dfm.registerDestinationFactory("http://cxf.apache.org/transports/http", transport);
+        
         dfm.registerDestinationFactory(MuleUniversalTransport.TRANSPORT_ID, transport);
 
         ConduitInitiatorManager extension = bus.getExtension(ConduitInitiatorManager.class);
@@ -91,6 +98,7 @@ public class CxfConfiguration implements Initialisable, Disposable, MuleContextA
         {
             // If unavailable eat exception and continue
         }
+        extension.registerConduitInitiator("http://cxf.apache.org/transports/http", transport);
         extension.registerConduitInitiator("http://schemas.xmlsoap.org/wsdl/soap/", transport);
         extension.registerConduitInitiator("http://schemas.xmlsoap.org/soap/http", transport);
         extension.registerConduitInitiator("http://schemas.xmlsoap.org/soap/http/", transport);
@@ -99,7 +107,19 @@ public class CxfConfiguration implements Initialisable, Disposable, MuleContextA
         extension.registerConduitInitiator("http://www.w3.org/2003/05/soap/bindings/HTTP/", transport);
         extension.registerConduitInitiator("http://cxf.apache.org/transports/http/configuration", transport);
         extension.registerConduitInitiator("http://cxf.apache.org/bindings/xformat", transport);
+        extension.registerConduitInitiator("http://cxf.apache.org/transports/jms", transport);
         extension.registerConduitInitiator(MuleUniversalTransport.TRANSPORT_ID, transport);
+        
+        bus.getOutInterceptors().add(new MuleProtocolHeadersOutInterceptor());
+        bus.getOutFaultInterceptors().add(new MuleProtocolHeadersOutInterceptor());
+
+        if (enableMuleSoapHeaders)
+        {
+            bus.getInInterceptors().add(new MuleHeadersInInterceptor());
+            bus.getInFaultInterceptors().add(new MuleHeadersInInterceptor());
+            bus.getOutInterceptors().add(new MuleHeadersOutInterceptor());
+            bus.getOutFaultInterceptors().add(new MuleHeadersOutInterceptor());
+        }
     }
 
     public void dispose()
@@ -175,5 +195,15 @@ public class CxfConfiguration implements Initialisable, Disposable, MuleContextA
         }
         return configuration;
     }
-    
+
+    public boolean isEnableMuleSoapHeaders()
+    {
+        return enableMuleSoapHeaders;
+    }
+
+    public void setEnableMuleSoapHeaders(boolean enableMuleSoapHeaders)
+    {
+        this.enableMuleSoapHeaders = enableMuleSoapHeaders;
+    }
+
 }
