@@ -1,5 +1,5 @@
 /*
- * $Id: NonRootServletTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: NonRootServletTestCase.java 22477 2011-07-20 15:27:35Z justin.calleja $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,13 +12,16 @@ package org.mule.module.cxf;
 
 public class NonRootServletTestCase extends ServletTestCase
 {
+    public NonRootServletTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
 
     @Override
     protected String getContextPath()
     {
         return "/foo";
     }
-
 }
 
 
