@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleConnection.java 21320 2011-02-20 08:01:36Z dirk.olmes $
+ * $Id: DefaultMuleConnection.java 22162 2011-06-09 18:23:00Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -172,7 +172,7 @@ public class DefaultMuleConnection implements MuleConnection
             message.setOutboundProperty(MuleProperties.MULE_USER_PROPERTY, "Plain " + credentials.getToken());
         }
 
-        return new DefaultMuleEvent(message, endpoint, session);
+        return new DefaultMuleEvent(message, endpoint.getExchangePattern(), session);
     }
 
     /**
