@@ -1,5 +1,5 @@
 /*
- * $Id: KBEStrategyUsingEncryptionTransformerTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: KBEStrategyUsingEncryptionTransformerTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,28 +10,38 @@
 
 package org.mule.module.pgp;
 
-import org.mule.DefaultMuleEvent;
 import org.mule.RequestContext;
+import org.mule.api.MuleEvent;
 import org.mule.tck.testmodels.fruit.Orange;
 import org.mule.transformer.encryption.EncryptionTransformer;
 import org.mule.transformer.simple.ByteArrayToObject;
 
+import java.io.InputStream;
+
+import org.apache.commons.io.IOUtils;
+import org.junit.Test;
+
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 public class KBEStrategyUsingEncryptionTransformerTestCase extends AbstractEncryptionStrategyTestCase
 {
+    @Test
     public void testEncrypt() throws Exception
     {
         String msg = "Test Message";
-        
-        DefaultMuleEvent event = (DefaultMuleEvent)getTestEvent(msg, getTestService("orange", Orange.class));
-        RequestContext.setEvent(event);
-        
+
+        MuleEvent event = getTestEvent(msg, getTestService("orange", Orange.class));
+        event = RequestContext.setEvent(event);
+
         EncryptionTransformer etrans = new EncryptionTransformer();
         etrans.setStrategy(kbStrategy);
         Object result = etrans.doTransform(msg.getBytes(), "UTF-8");
-        
+
         assertNotNull(result);
-        String encrypted = (String) new ByteArrayToObject().doTransform(result,"UTF-8");
+        InputStream inputStream = (InputStream) result;
+        String message = IOUtils.toString(inputStream);
+        String encrypted = (String) new ByteArrayToObject().doTransform(message.getBytes(), "UTF-8");
         assertTrue(encrypted.startsWith("-----BEGIN PGP MESSAGE-----"));
     }
 }
