@@ -1,5 +1,5 @@
 /*
- * $Id: HideExceptions.java 21886 2011-05-11 22:45:18Z pablo.kraan $
+ * $Id: HideExceptions.java 22711 2011-08-20 01:50:25Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,7 +12,7 @@ package org.mule.module.xml.functional;
 
 import org.mule.api.MuleEvent;
 import org.mule.api.exception.MessagingExceptionHandler;
-import org.mule.routing.filters.WildcardFilter;
+import org.mule.api.exception.RollbackSourceCallback;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -21,21 +21,16 @@ public class HideExceptions implements MessagingExceptionHandler
 {
     protected transient Log logger = LogFactory.getLog(getClass());
 
-    public MuleEvent handleException(Exception exception, MuleEvent event)
+    public MuleEvent handleException(Exception exception, MuleEvent event, RollbackSourceCallback rollbackMethod)
     {
         logger.debug("Hiding exception: " + exception);
         logger.debug("(see config for test - some exceptions expected)");
         return null;
     }
 
-    public WildcardFilter getCommitTxFilter()
+    public MuleEvent handleException(Exception exception, MuleEvent event)
     {
-        return null;
-    }
-
-    public WildcardFilter getRollbackTxFilter()
-    {
-        return null;
+        return handleException(exception, event, null);
     }
 }
 
