@@ -1,5 +1,5 @@
 /*
- * $Id: JXPathExpressionWithNamespaceTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: JXPathExpressionWithNamespaceTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,11 +18,12 @@ public class JXPathExpressionWithNamespaceTestCase extends AbstractXmlPropertyEx
 
     public static final String MESSAGE = "<foo:endpoint xmlns:foo=\"http://foo.com\">{0}</foo:endpoint>";
 
-    public JXPathExpressionWithNamespaceTestCase()
+    public JXPathExpressionWithNamespaceTestCase(ConfigVariant variant, String configResources)
     {
-        super(true);
+        super(variant, configResources, true);
     }
 
+    @Override
     protected Properties getStartUpProperties()
     {
         Properties p = new Properties();
@@ -32,11 +33,13 @@ public class JXPathExpressionWithNamespaceTestCase extends AbstractXmlPropertyEx
         return p;
     }
 
+    @Override
     protected Object getMatchMessage() throws Exception
     {
         return documentFor("matchingEndpoint1");
     }
 
+    @Override
     protected Object getErrorMessage() throws Exception
     {
         return documentFor("missingEndpoint");
