@@ -1,5 +1,5 @@
 /*
- * $Id: JXPathPropertyExtractorMultipleEndpointsTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: JXPathPropertyExtractorMultipleEndpointsTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,15 +12,15 @@ package org.mule.module.xml.functional;
 
 import java.util.Properties;
 
-
 public class JXPathPropertyExtractorMultipleEndpointsTestCase extends AbstractXmlPropertyExtractorTestCase
 {
 
-    public JXPathPropertyExtractorMultipleEndpointsTestCase()
+    public JXPathPropertyExtractorMultipleEndpointsTestCase(ConfigVariant variant, String configResources)
     {
-        super(true);
+        super(variant, configResources, true);
     }
 
+    @Override
     protected Properties getStartUpProperties()
     {
         Properties p = new Properties();
@@ -30,11 +30,13 @@ public class JXPathPropertyExtractorMultipleEndpointsTestCase extends AbstractXm
         return p;
     }
 
+    @Override
     protected Object getMatchMessage()
     {
         return "<endpoints><endpoint>matchingEndpoint1</endpoint><endpoint>matchingEndpoint2</endpoint></endpoints>";
     }
 
+    @Override
     protected Object getErrorMessage()
     {
         return "<endpoint>missingEndpoint</endpoint>";
