@@ -1,5 +1,5 @@
 /*
- * $Id: PrototypeObjectFactoryTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: PrototypeObjectFactoryTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,9 @@
 
 package org.mule.object;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotSame;
+
 public class PrototypeObjectFactoryTestCase extends AbstractObjectFactoryTestCase
 {
 
