@@ -1,5 +1,5 @@
 /*
- * $Id: FirstSuccessfulTestCase.java 21608 2011-03-28 08:30:16Z dirk.olmes $
+ * $Id: FirstSuccessfulTestCase.java 22597 2011-08-05 20:40:24Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
  *
@@ -10,24 +10,31 @@
 
 package org.mule.routing;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
+import org.mule.MessageExchangePattern;
 import org.mule.api.DefaultMuleException;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
 import org.mule.api.MuleSession;
-import org.mule.api.config.MuleProperties;
 import org.mule.api.processor.MessageProcessor;
 import org.mule.api.routing.CouldNotRouteOutboundMessageException;
 import org.mule.message.DefaultExceptionPayload;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 import org.mule.transformer.simple.StringAppendTransformer;
 
 import java.util.Arrays;
 import java.util.List;
 
-public class FirstSuccessfulTestCase extends AbstractMuleTestCase
+import org.junit.Test;
+
+public class FirstSuccessfulTestCase extends AbstractMuleContextTestCase
 {
     private static final String EXCEPTION_SEEN = "EXCEPTION WAS SEEN";
 
@@ -36,6 +43,7 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
         setStartContext(true);
     }
 
+    @Test
     public void testFirstSuccessful() throws Exception
     {
         MuleSession session = getTestSession(getTestService(), muleContext);
@@ -53,10 +61,12 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
         assertEquals(EXCEPTION_SEEN, getPayload(fs, session, "ABCDEFGHI"));
     }
 
+    @Test
     public void testFailureExpression() throws Exception
     {
         MessageProcessor intSetter = new MessageProcessor()
         {
+            @Override
             public MuleEvent process(MuleEvent event) throws MuleException
             {
                 event.getMessage().setPayload(Integer.valueOf(1));
@@ -71,10 +81,12 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
         assertEquals("abc", fs.process(getTestEvent("")).getMessageAsString());
     }
 
+    @Test
     public void testRouteReturnsNullEvent() throws Exception
     {
         MessageProcessor nullReturningMp = new MessageProcessor()
         {
+            @Override
             public MuleEvent process(MuleEvent event) throws MuleException
             {
                 return null;
@@ -86,10 +98,12 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
         assertNull(fs.process(getTestEvent("")));
     }
 
+    @Test
     public void testRouteReturnsNullMessage() throws Exception
     {
         MessageProcessor nullEventMp = new MessageProcessor()
         {
+            @Override
             public MuleEvent process(MuleEvent event) throws MuleException
             {
                 return new DefaultMuleEvent(null, event);
@@ -109,17 +123,15 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
         }
     }
 
+    @Test
     public void testProcessingIsForcedOnSameThread() throws Exception
     {
         MessageProcessor checkForceSyncFlag = new MessageProcessor()
         {
+            @Override
             public MuleEvent process(MuleEvent event) throws MuleException
             {
-                MuleMessage message = event.getMessage();
-                Boolean deliveryForcedInSameThread = message.getInboundProperty(
-                    MuleProperties.MULE_FORCE_SYNC_PROPERTY, Boolean.FALSE);
-                assertTrue(deliveryForcedInSameThread.booleanValue());
-
+                assertTrue(event.isSynchronous());
                 return event;
             }
         };
@@ -147,7 +159,7 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
         MuleMessage msg = new DefaultMuleMessage(message, muleContext);
         try
         {
-            MuleEvent event = mp.process(new DefaultMuleEvent(msg, null, session));
+            MuleEvent event = mp.process(new DefaultMuleEvent(msg, MessageExchangePattern.REQUEST_RESPONSE, session));
             MuleMessage returnedMessage = event.getMessage();
             if (returnedMessage.getExceptionPayload() != null)
             {
@@ -173,6 +185,7 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
             this.rejectIfMatches = rejectIfMatches;
         }
 
+        @Override
         public MuleEvent process(MuleEvent event) throws MuleException
         {
             try
@@ -192,7 +205,7 @@ public class FirstSuccessfulTestCase extends AbstractMuleTestCase
                 {
                     msg = new DefaultMuleMessage("No " + rejectIfMatches, muleContext);
                 }
-                return new DefaultMuleEvent(msg, null, event.getSession());
+                return new DefaultMuleEvent(msg, MessageExchangePattern.ONE_WAY, event.getSession());
             }
             catch (Exception e)
             {
