@@ -1,5 +1,5 @@
 /*
- * $Id: WireTapTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: WireTapTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,10 +13,17 @@ package org.mule.routing;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleMessage;
 import org.mule.api.routing.filter.Filter;
-import org.mule.tck.AbstractMuleTestCase;
 import org.mule.tck.SensingNullMessageProcessor;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
-public class WireTapTestCase extends AbstractMuleTestCase
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+
+public class WireTapTestCase extends AbstractMuleContextTestCase
 {
 
     protected SensingNullMessageProcessor tapListener;
@@ -32,9 +39,10 @@ public class WireTapTestCase extends AbstractMuleTestCase
         wireTap.setTap(tapListener);
     }
 
+    @Test
     public void testWireTapNoFilter() throws Exception
     {
-        MuleEvent event = getTestInboundEvent("data");
+        MuleEvent event = getTestEvent("data");
         MuleEvent primaryOutput = wireTap.process(event);
 
         assertSame(event, primaryOutput);
@@ -43,6 +51,7 @@ public class WireTapTestCase extends AbstractMuleTestCase
         assertEquals(event.getMessage().getPayload(), tapListener.event.getMessage().getPayload());
     }
 
+    @Test
     public void testWireTapFilterAccepted() throws Exception
     {
         wireTap.setFilter(new Filter()
@@ -53,7 +62,7 @@ public class WireTapTestCase extends AbstractMuleTestCase
             }
         });
 
-        MuleEvent event = getTestInboundEvent("data");
+        MuleEvent event = getTestEvent("data");
         MuleEvent primaryOutput = wireTap.process(event);
 
         assertSame(event, primaryOutput);
@@ -62,6 +71,7 @@ public class WireTapTestCase extends AbstractMuleTestCase
         assertEquals(event.getMessage().getPayload(), tapListener.event.getMessage().getPayload());
     }
 
+    @Test
     public void testWireTapFilterUnaccepted() throws Exception
     {
         wireTap.setFilter(new Filter()
@@ -72,7 +82,7 @@ public class WireTapTestCase extends AbstractMuleTestCase
             }
         });
 
-        MuleEvent event = getTestInboundEvent("data");
+        MuleEvent event = getTestEvent("data");
         MuleEvent primaryOutput = wireTap.process(event);
 
         assertSame(event, primaryOutput);
@@ -80,11 +90,12 @@ public class WireTapTestCase extends AbstractMuleTestCase
         assertNull(tapListener.event);
     }
 
+    @Test
     public void testWireTapNullTap() throws Exception
     {
         wireTap.setTap(null);
 
-        MuleEvent event = getTestInboundEvent("data");
+        MuleEvent event = getTestEvent("data");
         MuleEvent primaryOutput = wireTap.process(event);
 
         assertSame(event, primaryOutput);
