@@ -1,5 +1,5 @@
 /*
- * $Id: ExceptionBasedRouterTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: ExceptionBasedRouterTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,6 +12,7 @@ package org.mule.routing.outbound;
 
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
+import org.mule.MessageExchangePattern;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
@@ -23,15 +24,23 @@ import org.mule.api.routing.RoutingException;
 import org.mule.message.DefaultExceptionPayload;
 import org.mule.routing.LoggingCatchAllStrategy;
 import org.mule.routing.filters.RegExFilter;
-import org.mule.tck.AbstractMuleTestCase;
 import org.mule.tck.MuleTestUtils;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
 import com.mockobjects.dynamic.Mock;
 
 import java.util.ArrayList;
 import java.util.List;
 
-public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+public class ExceptionBasedRouterTestCase extends AbstractMuleContextTestCase
 {
     public ExceptionBasedRouterTestCase()
     {
@@ -43,14 +52,15 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
      * into sync mode. Test case ends here.
      */
     /* TODO MULE-4476
+    @Test
     public void testSuccessfulExceptionRouterAsynchronous() throws Exception
     {
         Mock mockSession = MuleTestUtils.getMockSession();
         mockSession.matchAndReturn("getFlowConstruct", getTestService());
-        
+
         DefaultOutboundRouterCollection messageRouter = new DefaultOutboundRouterCollection();
         messageRouter.setCatchAllStrategy(new LoggingCatchAllStrategy());
- 
+
         OutboundEndpoint endpoint1 = muleContext.getRegistry()
             .lookupEndpointFactory()
             .getOutboundEndpoint("test://Dummy1");
@@ -89,6 +99,7 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
     }
     */
 
+    @Test
     public void testSuccessfulExceptionRouterSynchronous() throws Exception
     {
         Mock mockSession = MuleTestUtils.getMockSession();
@@ -97,17 +108,15 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
         DefaultOutboundRouterCollection messageRouter = new DefaultOutboundRouterCollection();
         messageRouter.setCatchAllStrategy(new LoggingCatchAllStrategy());
 
-        OutboundEndpoint endpoint1 = muleContext.getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint("test://Dummy1?exchangePattern=request-response");
+        OutboundEndpoint endpoint1 =
+            muleContext.getEndpointFactory().getOutboundEndpoint("test://Dummy1?exchangePattern=request-response");
 
-        OutboundEndpoint endpoint2 = muleContext.getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint("test://Dummy2?exchangePattern=request-response");
+        OutboundEndpoint endpoint2 =
+            muleContext.getEndpointFactory().getOutboundEndpoint("test://Dummy2?exchangePattern=request-response");
+
+        OutboundEndpoint endpoint3 =
+            muleContext.getEndpointFactory().getOutboundEndpoint("test://Dummy3?exchangePattern=request-response");
 
-        OutboundEndpoint endpoint3 = muleContext.getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint("test://Dummy3?exchangePattern=request-response");
         Mock mockendpoint1 = RouterTestUtils.getMockEndpoint(endpoint1);
         Mock mockendpoint2 = RouterTestUtils.getMockEndpoint(endpoint2);
         Mock mockendpoint3 = RouterTestUtils.getMockEndpoint(endpoint3);
@@ -125,11 +134,11 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
         assertEquals(filter, router.getFilter());
 
         MuleMessage message = new DefaultMuleMessage("test event", muleContext);
-        MuleEvent event = new OutboundRoutingTestEvent(message, null);
+        MuleEvent event = new OutboundRoutingTestEvent(message, null, muleContext);
         // only one send should be called and succeed, the others should not be
         // called
         mockendpoint1.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(), event);
-        MuleEvent result = router.route(new OutboundRoutingTestEvent(message, (MuleSession)mockSession.proxy()));
+        MuleEvent result = router.route(new OutboundRoutingTestEvent(message, (MuleSession)mockSession.proxy(), muleContext));
         assertNotNull(result);
         assertEquals(message, result.getMessage());
         mockendpoint1.verify();
@@ -139,18 +148,18 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
      * Both targets fail during dispatch. The first endpoint should be forced into
      * sync mode.
      */
+    @Test
     public void testBothFailing() throws Exception
     {
         Mock mockSession = MuleTestUtils.getMockSession();
         mockSession.matchAndReturn("getFlowConstruct", getTestService());
 
-        OutboundEndpoint endpoint1 = muleContext.getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint("test://AlwaysFail");
+        OutboundEndpoint endpoint1 =
+            muleContext.getEndpointFactory().getOutboundEndpoint("test://AlwaysFail");
+
+        OutboundEndpoint endpoint2 =
+            muleContext.getEndpointFactory().getOutboundEndpoint("test://AlwaysFail");
 
-        OutboundEndpoint endpoint2 = muleContext.getRegistry()
-            .lookupEndpointFactory()
-            .getOutboundEndpoint("test://AlwaysFail");
         Mock mockendpoint1 = RouterTestUtils.getMockEndpoint(endpoint1);
         Mock mockendpoint2 = RouterTestUtils.getMockEndpoint(endpoint2);
 
@@ -171,14 +180,14 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
 
         // exception to throw
         MuleSession session = (MuleSession)mockSession.proxy();
-        MuleEvent eventToThrow = new DefaultMuleEvent(message, endpoint1, session);
+        MuleEvent eventToThrow = new DefaultMuleEvent(message, MessageExchangePattern.ONE_WAY, session);
         MuleException rex = new RoutingException(eventToThrow, endpoint1);
         mockendpoint1.expectAndThrow("process", RouterTestUtils.getArgListCheckerMuleEvent(), rex);
         mockendpoint2.expectAndThrow("process", RouterTestUtils.getArgListCheckerMuleEvent(), rex);
         MuleEvent result = null;
         try
         {
-            result = router.route(new OutboundRoutingTestEvent(message, session));
+            result = router.route(new OutboundRoutingTestEvent(message, session, muleContext));
             fail("Should have thrown exception as both targets would have failed");
         }
         catch (CouldNotRouteOutboundMessageException e)
@@ -195,14 +204,15 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
      * The first endpoint fails, second succeeds. Events are being sent
      * synchronously.
      */
+    @Test
     public void testFailFirstSuccessSecondSync() throws Exception
     {
         Mock mockSession = MuleTestUtils.getMockSession();
         mockSession.matchAndReturn("getFlowConstruct", getTestService());
 
-        OutboundEndpoint endpoint1 = getTestOutboundEndpoint("TestFailEndpoint", 
+        OutboundEndpoint endpoint1 = getTestOutboundEndpoint("TestFailEndpoint",
             "test://Failure?exchangePattern=request-response");
-        OutboundEndpoint endpoint2 = getTestOutboundEndpoint("TestSuccessEndpoint", 
+        OutboundEndpoint endpoint2 = getTestOutboundEndpoint("TestSuccessEndpoint",
             "test://Success?exchangePattern=request-response");
         Mock mockendpoint1 = RouterTestUtils.getMockEndpoint(endpoint1);
         Mock mockendpoint2 = RouterTestUtils.getMockEndpoint(endpoint2);
@@ -214,18 +224,18 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
 
         MuleMessage message = new DefaultMuleMessage("test event", muleContext);
         MuleMessage expectedResultMessage = new DefaultMuleMessage("Return event", muleContext);
-        MuleEvent event = new OutboundRoutingTestEvent(expectedResultMessage, null);
+        MuleEvent event = new OutboundRoutingTestEvent(expectedResultMessage, null, muleContext);
 
         assertTrue(router.isMatch(message));
 
         final MuleSession session = (MuleSession)mockSession.proxy();
         // exception to throw
-        MuleEvent eventToThrow = new DefaultMuleEvent(message, endpoint1, session);
+        MuleEvent eventToThrow = new DefaultMuleEvent(message, MessageExchangePattern.ONE_WAY, session);
         MuleException rex = new RoutingException(eventToThrow, endpoint1);
         // 1st failure
         mockendpoint1.expectAndThrow("process", RouterTestUtils.getArgListCheckerMuleEvent(), rex);
         mockendpoint2.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(), event);
-        MuleEvent actualResult = router.route(new OutboundRoutingTestEvent(message, session));
+        MuleEvent actualResult = router.route(new OutboundRoutingTestEvent(message, session, muleContext));
         mockendpoint1.verify();
         mockendpoint2.verify();
 
@@ -236,14 +246,15 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
      * The first endpoint fails, second succeeds. Events are being forced into a sync
      * mode, until we reach the last one.
      */
+    @Test
     public void testFailFirstSuccessSecondAsync() throws Exception
     {
         Mock mockSession = MuleTestUtils.getMockSession();
         mockSession.matchAndReturn("getFlowConstruct", getTestService());
 
-        OutboundEndpoint endpoint1 = getTestOutboundEndpoint("TestFailEndpoint", 
+        OutboundEndpoint endpoint1 = getTestOutboundEndpoint("TestFailEndpoint",
             "test://Failure?exchangePattern=request-response");
-        OutboundEndpoint endpoint2 = getTestOutboundEndpoint("TestSuccessEndpoint", 
+        OutboundEndpoint endpoint2 = getTestOutboundEndpoint("TestSuccessEndpoint",
             "test://Success?exchangePattern=one-way");
         Mock mockendpoint1 = RouterTestUtils.getMockEndpoint(endpoint1);
         Mock mockendpoint2 = RouterTestUtils.getMockEndpoint(endpoint2);
@@ -255,18 +266,18 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
 
         MuleMessage message = new DefaultMuleMessage("test event", muleContext);
         MuleMessage expectedResultMessage = new DefaultMuleMessage("Return event", muleContext);
-        MuleEvent event = new OutboundRoutingTestEvent(expectedResultMessage, null);
+        MuleEvent event = new OutboundRoutingTestEvent(expectedResultMessage, null, muleContext);
 
         assertTrue(router.isMatch(message));
 
         final MuleSession session = (MuleSession)mockSession.proxy();
         // exception to throw
-        MuleEvent eventToThrow = new DefaultMuleEvent(message, endpoint1, session);
+        MuleEvent eventToThrow = new DefaultMuleEvent(message, MessageExchangePattern.ONE_WAY, session);
         MuleException rex = new RoutingException(eventToThrow, endpoint1);
 
         mockendpoint1.expectAndThrow("process", RouterTestUtils.getArgListCheckerMuleEvent(), rex);
         mockendpoint2.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(), event);
-        MuleEvent actualResult = router.route(new OutboundRoutingTestEvent(message, session));
+        MuleEvent actualResult = router.route(new OutboundRoutingTestEvent(message, session, muleContext));
         assertNull("Async call should not return any results.", actualResult);
 
         mockendpoint1.verify();
@@ -277,14 +288,15 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
      * The first endpoint contains exception payload in return message, second
      * succeeds. Events are being sent synchronously.
      */
+    @Test
     public void testFirstHadExceptionPayloadSuccessSecondSyncWithExceptionPayload() throws Exception
     {
         Mock mockSession = MuleTestUtils.getMockSession();
         mockSession.matchAndReturn("getFlowConstruct", getTestService());
 
-        OutboundEndpoint endpoint1 = getTestOutboundEndpoint("TestFailEndpoint", 
+        OutboundEndpoint endpoint1 = getTestOutboundEndpoint("TestFailEndpoint",
             "test://Failure?exchangePattern=request-response");
-        OutboundEndpoint endpoint2 = getTestOutboundEndpoint("TestSuccessEndpoint", 
+        OutboundEndpoint endpoint2 = getTestOutboundEndpoint("TestSuccessEndpoint",
             "test://Success?exchangePattern=request-response");
         Mock mockendpoint1 = RouterTestUtils.getMockEndpoint(endpoint1);
         Mock mockendpoint2 = RouterTestUtils.getMockEndpoint(endpoint2);
@@ -295,7 +307,7 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
 
         MuleMessage message = new DefaultMuleMessage("test event", muleContext);
         MuleMessage expectedResultMessage = new DefaultMuleMessage("Return event", muleContext);
-        MuleEvent expectedResultEvent = new OutboundRoutingTestEvent(expectedResultMessage, null);
+        MuleEvent expectedResultEvent = new OutboundRoutingTestEvent(expectedResultMessage, null, muleContext);
 
 
         assertTrue(router.isMatch(message));
@@ -304,17 +316,17 @@ public class ExceptionBasedRouterTestCase extends AbstractMuleTestCase
         // message
         MuleMessage exPayloadMessage = new DefaultMuleMessage("there was a failure", muleContext);
         exPayloadMessage.setExceptionPayload(new DefaultExceptionPayload(new RuntimeException()));
-        MuleEvent exPayloadMessageEvent = new OutboundRoutingTestEvent(exPayloadMessage, null);
+        MuleEvent exPayloadMessageEvent = new OutboundRoutingTestEvent(exPayloadMessage, null, muleContext);
 
 
         final MuleSession session = (MuleSession)mockSession.proxy();
         // 1st failure
-        mockendpoint1.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(), 
+        mockendpoint1.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(),
             exPayloadMessageEvent);
         // next endpoint
-        mockendpoint2.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(), 
+        mockendpoint2.expectAndReturn("process", RouterTestUtils.getArgListCheckerMuleEvent(),
             expectedResultEvent);
-        MuleEvent actualResult = router.route(new OutboundRoutingTestEvent(message, session));
+        MuleEvent actualResult = router.route(new OutboundRoutingTestEvent(message, session, muleContext));
         mockendpoint1.verify();
         mockendpoint2.verify();
 
