@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractMuleTestCase.java 21929 2011-05-17 14:26:50Z dfeist $
+ * $Id: AbstractMuleTestCase.java 22606 2011-08-07 14:19:00Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -20,7 +20,6 @@ import org.mule.api.config.ConfigurationBuilder;
 import org.mule.api.context.MuleContextBuilder;
 import org.mule.api.context.MuleContextFactory;
 import org.mule.api.context.notification.MuleContextNotificationListener;
-import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.processor.MessageProcessor;
@@ -58,13 +57,12 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
 
 import junit.framework.TestCase;
 import junit.framework.TestResult;
 
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
-
 import org.apache.commons.collections.IteratorUtils;
 import org.apache.commons.collections.Predicate;
 import org.apache.commons.logging.Log;
@@ -128,9 +126,9 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
     private TestCaseWatchdog watchdog;
 
     protected int numPorts = 0;
-    
-    public List<Integer> ports = null;   
-    
+
+    public List<Integer> ports = null;
+
     static
     {
         String muleOpts = SystemUtils.getenv("MULE_TEST_OPTS");
@@ -413,7 +411,7 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
         // start a watchdog thread
         watchdog = createWatchdog();
         watchdog.start();
-       
+
         // set up the free ports
         if (numPorts > 0)
         {
@@ -422,14 +420,11 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
 
             //set the port properties
             setPortProperties();
-        }                
-        
+        }
+
         currentTestRunningThread = Thread.currentThread();
 
-        if (verbose)
-        {
-            System.out.println(StringMessageUtils.getBoilerPlate("Testing: " + getName(), '=', 80));
-        }
+        printTestHeader();
 
         try
         {
@@ -447,7 +442,7 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
                 // We dispose here just in case
                 disposeManager();
             }
-            
+
             muleContext = createMuleContext();
 
             // wait for Mule to fully start when requested (default)
@@ -485,6 +480,19 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
         }
     }
 
+    protected void printTestHeader()
+    {
+        if (verbose)
+        {
+            System.out.println(StringMessageUtils.getBoilerPlate(getTestHeader(), '=', 80));
+        }
+    }
+
+    protected String getTestHeader()
+    {
+        return "Testing: " + getName();
+    }
+
     protected MuleContext createMuleContext() throws Exception
     {
         // Should we set up the manager for every method?
@@ -695,19 +703,28 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
         return MuleTestUtils.getTestOutboundEndpoint(name, muleContext, null, transformers, null, null);
     }
 
-    public static InboundEndpoint getTestInboundEndpoint(String name, String uri, 
+    public static InboundEndpoint getTestInboundEndpoint(String name, String uri,
         List<Transformer> transformers, Filter filter, Map<Object, Object> properties, Connector connector) throws Exception
     {
         return MuleTestUtils.getTestInboundEndpoint(name, muleContext, uri, transformers, filter, properties, connector);
     }
 
-    public static OutboundEndpoint getTestOutboundEndpoint(String name, String uri, 
+    public static OutboundEndpoint getTestOutboundEndpoint(String name, String uri,
         List<Transformer> transformers, Filter filter, Map<Object, Object> properties) throws Exception
     {
         return MuleTestUtils.getTestOutboundEndpoint(name, muleContext, uri, transformers, filter, properties);
     }
 
-    public static OutboundEndpoint getTestOutboundEndpoint(String name, String uri, 
+    public static InboundEndpoint getTestInboundEndpoint(String name,
+                                                          String uri,
+                                                          List<Transformer> transformers,
+                                                          Filter filter,
+                                                          Map<Object, Object> properties) throws Exception
+    {
+        return MuleTestUtils.getTestInboundEndpoint(name, muleContext, uri, transformers, filter, properties);
+    }
+
+    public static OutboundEndpoint getTestOutboundEndpoint(String name, String uri,
         List<Transformer> transformers, Filter filter, Map<Object, Object> properties, Connector connector) throws Exception
     {
         return MuleTestUtils.getTestOutboundEndpoint(name, muleContext, uri, transformers, filter, properties, connector);
@@ -727,7 +744,7 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
     {
         return MuleTestUtils.getTestEvent(data, MessageExchangePattern.REQUEST_RESPONSE, muleContext);
     }
-    
+
     public static MuleEvent getTestEventUsingFlow(Object data) throws Exception
     {
         return MuleTestUtils.getTestEventUsingFlow(data, MessageExchangePattern.REQUEST_RESPONSE, muleContext);
@@ -738,20 +755,20 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
         return MuleTestUtils.getTestEvent(data, mep, muleContext);
     }
 
-    public static MuleEvent getTestInboundEvent(Object data, MuleSession session) throws Exception
+    public static MuleEvent getTestEvent(Object data, MuleSession session) throws Exception
     {
-        return MuleTestUtils.getTestInboundEvent(data, session, muleContext);
+        return MuleTestUtils.getTestEvent(data, session, muleContext);
     }
 
-    public static MuleEvent getTestInboundEvent(Object data) throws Exception
-    {
-        return MuleTestUtils.getTestInboundEvent(data, MessageExchangePattern.REQUEST_RESPONSE, muleContext);
-    }
-
-    public static MuleEvent getTestInboundEvent(Object data, MessageExchangePattern mep) throws Exception
-    {
-        return MuleTestUtils.getTestInboundEvent(data, mep, muleContext);
-    }
+//    public static MuleEvent getTestInboundEvent(Object data) throws Exception
+//    {
+//        return MuleTestUtils.getTestInboundEvent(data, MessageExchangePattern.REQUEST_RESPONSE, muleContext);
+//    }
+//
+//    public static MuleEvent getTestInboundEvent(Object data, MessageExchangePattern mep) throws Exception
+//    {
+//        return MuleTestUtils.getTestInboundEvent(data, mep, muleContext);
+//    }
 
     public static MuleEventContext getTestEventContext(Object data) throws Exception
     {
@@ -768,12 +785,12 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
         return MuleTestUtils.getTestTransformer();
     }
 
-    public static MuleEvent getTestEvent(Object data, ImmutableEndpoint endpoint) throws Exception
+    public static MuleEvent getTestEvent(Object data, InboundEndpoint endpoint) throws Exception
     {
         return MuleTestUtils.getTestEvent(data, endpoint, muleContext);
     }
 
-    public static MuleEvent getTestEvent(Object data, Service service, ImmutableEndpoint endpoint)
+    public static MuleEvent getTestEvent(Object data, Service service, InboundEndpoint endpoint)
             throws Exception
     {
         return MuleTestUtils.getTestEvent(data, service, endpoint, muleContext);
@@ -993,12 +1010,12 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
     {
         muleContext.getRegistry().registerObject(String.valueOf(o.hashCode()), o);
     }
-    
+
     public SensingNullMessageProcessor getSensingNullMessageProcessor()
     {
         return new SensingNullMessageProcessor();
     }
-    
+
     public TriggerableMessageSource getTriggerableMessageSource(MessageProcessor listener)
     {
         return new TriggerableMessageSource(listener);
@@ -1023,5 +1040,5 @@ public abstract class AbstractMuleTestCase extends TestCase implements TestCaseW
     public List<Integer> getPorts()
     {
         return ports;
-    }    
+    }
 }
