@@ -1,5 +1,5 @@
 /*
- * $Id: ComponentReturningNullFlowTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: ComponentReturningNullFlowTestCase.java 22421 2011-07-15 05:05:06Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,17 +12,35 @@ package org.mule.test.components;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.transport.NullPayload;
 
-public class ComponentReturningNullFlowTestCase extends FunctionalTestCase
-{
+import java.util.Arrays;
+import java.util.Collection;
 
-    protected String getConfigResources()
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
+public class ComponentReturningNullFlowTestCase extends AbstractServiceAndFlowTestCase
+{
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        return "org/mule/test/components/component-returned-null.xml";
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "org/mule/test/components/component-returned-null-service.xml"},
+            {ConfigVariant.FLOW, "org/mule/test/components/component-returned-null-flow.xml"}});
     }
 
+    public ComponentReturningNullFlowTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
+    @Test
     public void testNullReturnStopsFlow() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
