@@ -1,5 +1,5 @@
 /*
- * $Id: SystemExceptionStrategyTestCase.java 19692 2010-09-21 23:50:35Z aperepel $
+ * $Id: SystemExceptionStrategyTestCase.java 22419 2011-07-15 03:41:06Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,16 +13,22 @@ package org.mule.test.integration.exceptions;
 import org.mule.api.lifecycle.LifecycleException;
 import org.mule.tck.testmodels.mule.TestConnector;
 
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeUnit;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
 
 public class SystemExceptionStrategyTestCase extends AbstractExceptionStrategyTestCase
 {
+    
     @Override
     protected String getConfigResources()
     {
         return "org/mule/test/integration/exceptions/system-exception-strategy.xml";
     }
 
+    @Test
     public void testConnectorStartup() throws Exception
     {
         try
@@ -41,6 +47,7 @@ public class SystemExceptionStrategyTestCase extends AbstractExceptionStrategyTe
         assertEquals(1, systemExceptionCounter.get());
     }
 
+    @Test
     public void testConnectorPolling() throws Exception
     {
         muleContext.getRegistry().lookupService("Polling").start();
