@@ -1,5 +1,5 @@
 /*
- * $Id: SessionPropertyChainingRouterTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: SessionPropertyChainingRouterTestCase.java 22686 2011-08-16 19:39:20Z pablo.lagreca $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,20 +12,30 @@ package org.mule.test.integration.message;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
 import org.mule.tck.NonSerializableObject;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 /**
- * @see EE-1821
+ * @see EE-2307
+ *
+ * Non serializable session properties won't be serialized with the mule session
+ * but neither it will be lost in the flow were it was stored
  */
 public class SessionPropertyChainingRouterTestCase extends FunctionalTestCase
 {
+
     @Override
     protected String getConfigResources()
     {
         return "org/mule/test/integration/messaging/session-property-chaining-router.xml";
     }
 
+    @Test
     public void testRouter() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
