@@ -1,5 +1,5 @@
 /*
- * $Id: AsyncReplyNoTimeoutTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: AsyncReplyNoTimeoutTestCase.java 22422 2011-07-15 08:22:16Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,15 +13,24 @@ package org.mule.test.integration.routing;
 import org.mule.api.MuleMessage;
 import org.mule.api.MuleMessageCollection;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
 public class AsyncReplyNoTimeoutTestCase extends FunctionalTestCase
 {
+    
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/test/integration/routing/multi-async-repy-no-timeout.xml";
     }
 
+    @Test
     public void testAggregatorWithNoTimeout() throws Exception
     {
         String message = "test";
