@@ -1,5 +1,5 @@
 /*
- * $Id: AddReceivedNodeService.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: AddReceivedNodeService.java 22334 2011-07-06 06:52:14Z claude.mamo $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -7,30 +7,20 @@
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
+
 package org.mule.test.integration.routing.outbound;
 
-import org.mule.api.service.Service;
-import org.mule.api.service.ServiceAware;
-
 import org.dom4j.Document;
-import org.dom4j.Element;
 
 /**
  * TODO
  */
-public class AddReceivedNodeService implements ServiceAware
+public class AddReceivedNodeService
 {
-    private Service service;
-
-    public void setService(Service service)
-    {
-        this.service = service;
-    }
-
     public Document addNodeTo(Document doc)
     {
-        Element e = doc.getRootElement().addElement("Received");
-        e.setText(service.getName());
+        doc.getRootElement().addElement("Received");
+
         return doc;
     }
 }
