@@ -1,5 +1,5 @@
 /*
- * $Id: ExpressionRecipientListSyncTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: ExpressionRecipientListSyncTestCase.java 22422 2011-07-15 08:22:16Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,19 +13,37 @@ package org.mule.test.integration.routing.outbound;
 import org.mule.api.MuleMessage;
 import org.mule.api.MuleMessageCollection;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 
-public class ExpressionRecipientListSyncTestCase extends FunctionalTestCase
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
+public class ExpressionRecipientListSyncTestCase extends AbstractServiceAndFlowTestCase
 {
-    @Override
-    protected String getConfigResources()
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        return "org/mule/test/integration/routing/outbound/expression-recipient-list-sync-test.xml";
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "org/mule/test/integration/routing/outbound/expression-recipient-list-sync-test-service.xml"},
+            {ConfigVariant.FLOW, "org/mule/test/integration/routing/outbound/expression-recipient-list-sync-test-flow.xml"}
+        });
     }
 
+    public ExpressionRecipientListSyncTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
+    @Test
     public void testRecipientList() throws Exception
     {
         String message = "test";
@@ -37,7 +55,7 @@ public class ExpressionRecipientListSyncTestCase extends FunctionalTestCase
         MuleMessage result = client.send("vm://distributor.queue", message, props);
 
         assertNotNull(result);
-        
+
         assertTrue(result instanceof MuleMessageCollection);
         MuleMessageCollection coll = (MuleMessageCollection)result;
         assertEquals(3, coll.size());
