@@ -1,5 +1,5 @@
 /*
- * $Id: ServiceInFlightMessagesTestCase.java 21229 2011-02-10 02:41:30Z dfeist $
+ * $Id: ServiceInFlightMessagesTestCase.java 22431 2011-07-18 07:40:35Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -15,17 +15,20 @@ import org.mule.api.MuleException;
 import org.mule.api.service.Service;
 import org.mule.config.DefaultMuleConfiguration;
 import org.mule.context.DefaultMuleContextBuilder;
-import org.mule.tck.FunctionalTestCase;
-import org.mule.util.queue.FilePersistenceStrategy;
-import org.mule.util.queue.QueueManager;
-import org.mule.util.queue.TransactionalQueueManager;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.util.store.QueuePersistenceObjectStore;
 
 import java.io.File;
 
 import org.apache.commons.io.FileUtils;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 
 public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
 {
+
     protected static final int WAIT_TIME_MILLIS = 500;
     protected static final int NUM_MESSAGES = 500;
 
@@ -39,9 +42,9 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
     protected MuleContext createMuleContext() throws Exception
     {
         // Use a graceful shutdown but not the full 5s default
-        MuleContext muleContext = super.createMuleContext();
-        ((DefaultMuleConfiguration) muleContext.getConfiguration()).setShutdownTimeout(WAIT_TIME_MILLIS);
-        return muleContext;
+        MuleContext context = super.createMuleContext();
+        ((DefaultMuleConfiguration) context.getConfiguration()).setShutdownTimeout(WAIT_TIME_MILLIS);
+        return context;
     }
 
     @Override
@@ -51,6 +54,7 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
         super.doTearDown();
     }
 
+    @Test
     public void testInFlightMessagesWhenServiceStopped() throws Exception
     {
         Service service = muleContext.getRegistry().lookupService("TestService");
@@ -64,6 +68,7 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
         assertSedaQueueEmpty(service);
     }
 
+    @Test
     public void testInFlightMessagesPausedServiceWhenServiceStopped() throws Exception
     {
         Service service = muleContext.getRegistry().lookupService("PausedTestService");
@@ -79,6 +84,7 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
         assertOutboundEmpty();
     }
 
+    @Test
     public void testInFlightMessagesPersistentQueueServiceWhenServiceStopped() throws Exception
     {
         Service service = muleContext.getRegistry().lookupService("TestPersistentQueueService");
@@ -105,6 +111,7 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
         assertSedaQueueEmpty(service);
     }
 
+    @Test
     public void testInFlightMessagesPausedPersistentQueueServiceWhenServiceStopped() throws Exception
     {
         Service service = muleContext.getRegistry().lookupService("PausedTestPersistentQueueService");
@@ -127,13 +134,14 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
         // Let mule finish up with the rest of the messages until seda queue is empty
         startService(service);
         service.resume();
-        Thread.sleep(WAIT_TIME_MILLIS * 10);
+        Thread.sleep(WAIT_TIME_MILLIS * 20);
         stopService(service);
 
         assertNoLostMessages(NUM_MESSAGES, service);
         assertSedaQueueEmpty(service);
     }
 
+    @Test
     public void testInFlightMessagesPersistentQueueServiceWhenMuleDisposed() throws Exception
     {
         Service service = muleContext.getRegistry().lookupService("TestPersistentQueueService");
@@ -177,7 +185,7 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
      * After each run the following should total 500 events: 1) Event still in SEDA
      * queue 2) Events dispatched to outbound vm endpooint 3) Events that were unable
      * to be sent to stopped service and raised exceptions
-     * 
+     *
      * @throws Exception
      */
     protected synchronized void assertNoLostMessages(int numMessages, Service service) throws Exception
@@ -231,16 +239,13 @@ public class ServiceInFlightMessagesTestCase extends FunctionalTestCase
         }
         else
         {
+            // Don;t fool around trying to use objects that weren't started fully, just go to the disk
             MuleContext localMuleContext = new DefaultMuleContextBuilder().buildMuleContext();
-            QueueManager queueManager = new TransactionalQueueManager();
-            FilePersistenceStrategy persistenceStrategy = new FilePersistenceStrategy();
-            persistenceStrategy.setMuleContext(localMuleContext);
-            queueManager.setPersistenceStrategy(persistenceStrategy);
-            queueManager.start();
-            int size = queueManager.getQueueSession().getQueue(name).size();
-            queueManager.stop();
-            localMuleContext = null;
-            return size;
+            String workingDirectory = localMuleContext.getConfiguration().getWorkingDirectory();
+            String path = workingDirectory + File.separator + QueuePersistenceObjectStore.DEFAULT_QUEUE_STORE + File.separator + name;
+
+            File[] filesInQueue = new File(path).listFiles();
+            return filesInQueue.length;
         }
     }
 
