@@ -1,5 +1,5 @@
 /*
- * $Id: CxfOverJMSTestCase.java 20527 2010-12-08 21:13:02Z dzapata $
+ * $Id: CxfOverJMSTestCase.java 22431 2011-07-18 07:40:35Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,9 +14,19 @@ import org.mule.DefaultMuleMessage;
 import org.mule.api.MuleMessage;
 import org.mule.api.transport.PropertyScope;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 
-public class CxfOverJMSTestCase extends FunctionalTestCase
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Ignore;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
+public class CxfOverJMSTestCase extends AbstractServiceAndFlowTestCase
 {
     private static final String req = "<soap:Envelope xmlns:soap=\"http://schemas.xmlsoap.org/soap/envelope/\">"
                                       + "<soap:Body>"
@@ -26,12 +36,21 @@ public class CxfOverJMSTestCase extends FunctionalTestCase
                                       + "</soap:Body>"
                                       + "</soap:Envelope>";
 
-    @Override
-    protected String getConfigResources()
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        return "org/mule/test/integration/transport/cxf/cxf-over-jms-config.xml";
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "org/mule/test/integration/transport/cxf/cxf-over-jms-config-service.xml"},
+            {ConfigVariant.FLOW, "org/mule/test/integration/transport/cxf/cxf-over-jms-config-flow.xml"}
+        });
     }
 
+    public CxfOverJMSTestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
+    }
+
+    @Test
     public void testCxf() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -41,6 +60,7 @@ public class CxfOverJMSTestCase extends FunctionalTestCase
         assertTrue(message.getPayloadAsString().indexOf("return>hello") != -1);
     }
 
+    @Test
     public void testCxfClientOverJMS() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -54,7 +74,9 @@ public class CxfOverJMSTestCase extends FunctionalTestCase
     }
 
     // MULE-4677
-    public void XXtestCxfOverJMSSyncProxy() throws Exception
+    @Ignore
+    @Test
+    public void testCxfOverJMSSyncProxy() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
         MuleMessage result = client.send("http://localhost:63081/services/testBridge",
