@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractJmsRequestFromScriptTestCase.java 19692 2010-09-21 23:50:35Z aperepel $
+ * $Id: AbstractJmsRequestFromScriptTestCase.java 22620 2011-08-09 10:02:17Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,13 +12,18 @@ package org.mule.test.integration.transport.jms.scripting;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
 
 /**
  * Defines a scenario when we request a jms message from inside a groovy script
  * which is executed as part of a service whose endpoints are jms ones.
  * Subclasses must provide the service configuration through the implementation
- * of {@link org.mule.tck.FunctionalTestCase#getConfigResources()}.
+ * of {@link org.mule.tck.junit4.FunctionalTestCase#getConfigResources()}.
  */
 public abstract class AbstractJmsRequestFromScriptTestCase extends FunctionalTestCase
 {
@@ -29,6 +34,7 @@ public abstract class AbstractJmsRequestFromScriptTestCase extends FunctionalTes
      * a couple of jms message in a queue so the script will have data to
      * process.
      */
+    @Test
     public void testRequestingMessageFromScript() throws Exception
     {
         MuleClient muleClient = new MuleClient(muleContext);
