@@ -1,5 +1,5 @@
 /*
- * $Id: ClientBridgeTestCase.java 19856 2010-10-06 21:36:13Z dzapata $
+ * $Id: ClientBridgeTestCase.java 22450 2011-07-19 08:20:41Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,17 +12,29 @@ package org.mule.test.usecases.axis.clientbridge;
 
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 
-public class ClientBridgeTestCase extends DynamicPortTestCase
+import org.junit.Rule;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
+public class ClientBridgeTestCase extends FunctionalTestCase
 {
 
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");
+
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/test/usecases/axis/clientbridge/client-mule-config.xml";
     }
 
+    @Test
     public void testBridgeVMToAxis() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -33,12 +45,6 @@ public class ClientBridgeTestCase extends DynamicPortTestCase
         ComplexData result = (ComplexData)message.getPayload();
         assertEquals(new Integer(84), result.getSomeInteger());
         assertEquals("Foo", result.getSomeString());
-
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
 }
