@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultReplyToHandler.java 20740 2010-12-15 10:29:17Z dirk.olmes $
+ * $Id: DefaultReplyToHandler.java 22808 2011-08-31 04:13:19Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -22,12 +22,19 @@ import org.mule.api.endpoint.EndpointFactory;
 import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.service.Service;
-import org.mule.api.transformer.Transformer;
+import org.mule.api.transport.Connector;
 import org.mule.api.transport.DispatchException;
 import org.mule.api.transport.ReplyToHandler;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.management.stats.ServiceStatistics;
+import org.mule.transport.service.TransportFactory;
+import org.mule.util.ObjectNameHelper;
+import org.mule.util.store.DeserializationPostInitialisable;
 
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.ObjectOutputStream;
+import java.io.Serializable;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -40,20 +47,25 @@ import org.apache.commons.logging.LogFactory;
  * replyTo header.
  */
 
-public class DefaultReplyToHandler implements ReplyToHandler
+public class DefaultReplyToHandler implements ReplyToHandler, Serializable, DeserializationPostInitialisable
 {
+    /**
+     * Serial version
+     */
+    private static final long serialVersionUID = 1L;
+
     /**
      * logger used by this class
      */
-    protected transient final Log logger = LogFactory.getLog(getClass());
+    protected transient Log logger = LogFactory.getLog(getClass());
 
-    private volatile List<Transformer> transformers;
-    private final Map<String, ImmutableEndpoint> endpointCache = new HashMap<String, ImmutableEndpoint>();
-    protected MuleContext muleContext;
+    private transient Map<String, ImmutableEndpoint> endpointCache = new HashMap<String, ImmutableEndpoint>();
+    protected transient MuleContext muleContext;
+    protected transient Connector connector;
+    private transient Map<String, Object> serializedData = null;
 
-    public DefaultReplyToHandler(List<Transformer> transformers, MuleContext muleContext)
+    public DefaultReplyToHandler(MuleContext muleContext)
     {
-        this.transformers = transformers;
         this.muleContext = muleContext;
     }
 
@@ -80,7 +92,7 @@ public class DefaultReplyToHandler implements ReplyToHandler
         returnMessage = new DefaultMuleMessage(returnMessage.getPayload(), returnMessage, muleContext);
 
         // Create the replyTo event asynchronous
-        MuleEvent replyToEvent = new DefaultMuleEvent(returnMessage, endpoint, event.getSession(), event.getProcessingTime());
+        MuleEvent replyToEvent = new DefaultMuleEvent(returnMessage, event);
 
         // carry over properties
         List<String> responseProperties = endpoint.getResponseProperties();
@@ -123,25 +135,86 @@ public class DefaultReplyToHandler implements ReplyToHandler
         OutboundEndpoint endpoint = (OutboundEndpoint) endpointCache.get(endpointUri);
         if (endpoint == null)
         {
-            EndpointFactory endpointFactory = muleContext.getRegistry().lookupEndpointFactory();
+            EndpointFactory endpointFactory = muleContext.getEndpointFactory();
             EndpointBuilder endpointBuilder = endpointFactory.getEndpointBuilder(endpointUri);
-            if (transformers == null)
-            {
-                endpointBuilder.setTransformers(event.getEndpoint().getResponseTransformers());
-            }
             endpoint = endpointFactory.getOutboundEndpoint(endpointBuilder);
             endpointCache.put(endpointUri, endpoint);
         }
         return endpoint;
     }
 
-    public List<Transformer> getTransformers()
+    @SuppressWarnings({"unused", "unchecked"})
+    public void initAfterDeserialisation(MuleContext muleContext) throws MuleException
     {
-        return transformers;
+        // this method can be called even on objects that were not serialized. In this case,
+        // the temporary holder for serialized data is not initialized and we can just return
+        if (serializedData == null)
+        {
+            return;
+        }
+        this.muleContext = muleContext;
+        logger = LogFactory.getLog(getClass());
+        endpointCache = new HashMap<String, ImmutableEndpoint>();
+        connector = findConnector();
+        serializedData = null;
     }
 
-    public void setTransformers(List<Transformer> transformers)
+    public Connector getConnector()
     {
-        this.transformers = transformers;
+        return connector;
     }
-}
+
+    protected Connector findConnector()
+    {
+        String connectorName = (String) serializedData.get("connectorName");
+        String connectorType = (String) serializedData.get("connectorType");
+        Connector found =  null;
+
+        if (connectorName != null)
+        {
+            found = muleContext.getRegistry().get(connectorName);
+        }
+        else if (connectorType != null)
+        {
+            found = new TransportFactory(muleContext).getDefaultConnectorByProtocol(connectorType);
+        }
+        return found;
+    }
+
+    private void writeObject(ObjectOutputStream out) throws IOException
+    {
+        out.defaultWriteObject();
+
+        String connectorName = null;
+        String connectorType = null;
+
+        //Can be null if service call originates from MuleClient
+        if (serializedData != null)
+        {
+            connectorName = (String) serializedData.get("connectorName");
+            connectorType = (String) serializedData.get("connectorType");
+        }
+        else
+        {
+            if (connector != null)
+            {
+                if (!ObjectNameHelper.isDefaultAutoGeneratedConnector(connector))
+                {
+                    connectorName = connector.getName();
+                }
+                connectorType = connector.getProtocol();
+            }
+        }
+        out.writeObject(connectorName);
+        out.writeObject(connectorType);
+    }
+
+    private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
+    {
+        in.defaultReadObject();
+        serializedData = new HashMap<String, Object>();
+
+        serializedData.put("connectorName", in.readObject());
+        serializedData.put("connectorType", in.readObject());
+    }
+}
\ No newline at end of file
