@@ -1,5 +1,5 @@
 /*
- * $Id: AjaxFunctionalTestCase.java 21169 2011-02-01 19:35:38Z dzapata $
+ * $Id: AjaxFunctionalTestCase.java 22460 2011-07-20 07:44:33Z claude.mamo $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,49 +10,64 @@
 
 package org.mule.transport.ajax;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 import org.mule.util.concurrent.Latch;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.Map;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
 
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
-
 import org.codehaus.jackson.map.ObjectMapper;
 import org.cometd.Client;
 import org.cometd.Message;
 import org.cometd.MessageListener;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 import org.mortbay.cometd.client.BayeuxClient;
 import org.mortbay.jetty.client.Address;
 import org.mortbay.jetty.client.HttpClient;
 
-public class AjaxFunctionalTestCase extends DynamicPortTestCase
+public class AjaxFunctionalTestCase extends AbstractServiceAndFlowTestCase
 {
     public static int SERVER_PORT = -1;
     
     private HttpClient httpClient;
     private BayeuxClient bayeuxClient;
 
-    public AjaxFunctionalTestCase()
+    @Rule
+    public DynamicPort dynamicPort = new DynamicPort("port1");
+
+    public AjaxFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        super();
         // start the embedded servers before starting mule to try and avoid
-        // intermittent failures in testClientPublishWithString        
+        // intermittent failures in testClientPublishWithString
+        super(variant, configResources);
         setStartContext(false);
     }
 
-    @Override
-    protected String getConfigResources()
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        return "ajax-embedded-functional-test.xml";
-    }
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "ajax-embedded-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "ajax-embedded-functional-test-flow.xml"}
+        });
+    }      
 
     @Override
     protected void doSetUp() throws Exception
     {
-        SERVER_PORT = getPorts().get(0);
+        SERVER_PORT = dynamicPort.getNumber();
         httpClient = new HttpClient();
         httpClient.setConnectorType(HttpClient.CONNECTOR_SELECT_CHANNEL);
         httpClient.start();
@@ -94,6 +109,7 @@ public class AjaxFunctionalTestCase extends DynamicPortTestCase
         }
     }
 
+    @Test
     public void testClientSubscribeWithString() throws Exception
     {
         /*
@@ -106,6 +122,7 @@ public class AjaxFunctionalTestCase extends DynamicPortTestCase
         final AtomicReference<Object> data = new AtomicReference<Object>();
         bayeuxClient.addListener(new MessageListener()
         {
+            @Override
             public void deliver(Client fromClient, Client toClient, Message message)
             {
 
@@ -127,25 +144,21 @@ public class AjaxFunctionalTestCase extends DynamicPortTestCase
         
         // parse the result string into java objects.  different jvms return it in different order, so we can't do a straight string comparison 
         ObjectMapper mapper = new ObjectMapper();
-        Map result  = mapper.readValue((String) data.get(), Map.class);
+        Map<?, ?> result  = mapper.readValue((String) data.get(), Map.class);
         assertEquals("/test1", result.get("channel"));
         assertEquals("Ross Received", result.get("data"));
     }
 
+    @Test
     public void testClientPublishWithString() throws Exception
     {
         MuleClient muleClient = new MuleClient(muleContext);
 
         bayeuxClient.publish("/test2", "Ross", null);
-        MuleMessage msg = muleClient.request("vm://in2", RECEIVE_TIMEOUT);
+        MuleMessage msg = muleClient.request("vm://in2", RECEIVE_TIMEOUT * 2);
 
         assertNotNull(msg);
         assertEquals("Ross Received", msg.getPayloadAsString());
     }
 
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
 }
