@@ -1,5 +1,5 @@
 /*
- * $Id: AjaxConnector.java 21371 2011-03-01 17:01:44Z tcarlson $
+ * $Id: AjaxConnector.java 22497 2011-07-21 12:12:26Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -208,7 +208,7 @@ public class AjaxConnector extends JettyHttpsConnector implements BayeuxAware
     @Override
     public ReplyToHandler getReplyToHandler(ImmutableEndpoint endpoint)
     {
-        return new AjaxReplyToHandler(getDefaultResponseTransformers(endpoint), this);
+        return new AjaxReplyToHandler(this);
     }
 
     void createEmbeddedServer() throws MuleException
