@@ -1,5 +1,5 @@
 /*
- * $Id: RetrieveMessageReceiver.java 19698 2010-09-22 18:33:58Z esteban.robles $
+ * $Id: RetrieveMessageReceiver.java 22396 2011-07-12 21:26:04Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,6 +12,7 @@ package org.mule.transport.email;
 
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
+import org.mule.api.MuleRuntimeException;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.lifecycle.CreateException;
@@ -26,6 +27,8 @@ import org.mule.util.UUID;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.List;
 
 import javax.mail.Address;
 import javax.mail.Flags;
@@ -119,79 +122,86 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
         folder.addMessageCountListener(this);
     }
 
-    public void messagesAdded(MessageCountEvent event)
+    public void messagesAdded(MessageCountEvent event) 
     {
-        Message messages[] = event.getMessages();
-        if (messages != null)
+        try
         {
-            MuleMessage message = null;
-            for (int i = 0; i < messages.length; i++)
+            Message messages[] = event.getMessages();
+            List<Message> processedMessages = new ArrayList<Message>();
+            if (messages != null)
             {
-                try
+                MuleMessage message = null;
+                for (int i = 0; i < messages.length; i++)
                 {
-                    if (!messages[i].getFlags().contains(Flags.Flag.DELETED)
-                        && !messages[i].getFlags().contains(Flags.Flag.SEEN))
+                    if (getLifecycleState().isStopping())
                     {
-                        MimeMessage mimeMessage = new MimeMessage((MimeMessage) messages[i]);
-                        storeMessage(mimeMessage);
-                        message = createMuleMessage(mimeMessage, endpoint.getEncoding());
-
-                        if (castConnector().isDeleteReadMessages())
+                        break;
+                    }
+                    processedMessages.add(messages[i]);
+                    try
+                    {
+                        if (!messages[i].getFlags().contains(Flags.Flag.DELETED)
+                            && !messages[i].getFlags().contains(Flags.Flag.SEEN))
                         {
-                            // Mark as deleted
-                            messages[i].setFlag(Flags.Flag.DELETED, true);
-                        }
-                        else
-                        {
-                            if (this.getEndpoint().getFilter().accept(message))
+                            MimeMessage mimeMessage = new MimeMessage((MimeMessage) messages[i]);
+                            storeMessage(mimeMessage);
+                            message = createMuleMessage(mimeMessage, endpoint.getEncoding());
+    
+                            if (castConnector().isDeleteReadMessages())
                             {
-                                Flags.Flag flag = castConnector().getDefaultProcessMessageAction();
-                                if (flag != null)
-                                {
-                                    messages[i].setFlag(flag, true);
-                                }
+                                // Mark as deleted
+                                messages[i].setFlag(Flags.Flag.DELETED, true);
                             }
                             else
                             {
-                                messages[i].setFlag(Flags.Flag.SEEN, false);
+                                if (this.getEndpoint().getFilter() != null && this.getEndpoint().getFilter().accept(message))
+                                {
+                                    Flags.Flag flag = castConnector().getDefaultProcessMessageAction();
+                                    if (flag != null)
+                                    {
+                                        messages[i].setFlag(flag, true);
+                                    }
+                                }
+                                else
+                                {
+                                    messages[i].setFlag(Flags.Flag.SEEN, false);
+                                }
                             }
-                       }
-                        routeMessage(message);
+    
+                            routeMessage(message);
+                        }
+                    }
+                    catch (MuleException e)
+                    {
+                        throw e;
+                    }
+                    catch (Exception e)
+                    {
+                        Exception forwarded;
+    
+                        if (message != null)
+                        {
+                            forwarded = new org.mule.api.MessagingException(EmailMessages.routingError(), message, e);
+                        }
+                        else
+                        {
+                            forwarded = new ReceiveException(endpoint, -1, e);
+                        }
+                        throw forwarded;
                     }
                 }
-                catch (MuleException e)
+                // Lets move all messages in one go
+                if (moveToFolder != null)
                 {
-                    getConnector().getMuleContext().getExceptionListener().handleException(e);
-                }
-                catch (Exception e)
-                {
-                    Exception forwarded;
-
-                    if (message != null)
-                    {
-                        forwarded = new org.mule.api.MessagingException(EmailMessages.routingError(), message, e);
-                    }
-                    else
-                    {
-                        forwarded = new ReceiveException(endpoint, -1, e);
-                    }
-
-                    getConnector().getMuleContext().getExceptionListener().handleException(forwarded);
-                }
-            }
-            // Lets move all messages in one go
-            if (moveToFolder != null)
-            {
-                try
-                {
-                    folder.copyMessages(messages, moveToFolder);
-                }
-                catch (MessagingException e)
-                {
-                    getConnector().getMuleContext().getExceptionListener().handleException(e);
+                    folder.copyMessages(processedMessages.toArray(new Message[processedMessages.size()]), moveToFolder);
                 }
             }
         }
+        catch (Exception e)
+        {
+            // Throw a runtime exception because the javax.mail API does not allow a checked exception on this method.
+            throw new MuleRuntimeException(e);
+        }
     }
 
     public void messagesRemoved(MessageCountEvent event)
@@ -248,7 +258,7 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
      * POP3
      * <p/>
      * message will be deleted from the server
-     * 
+     *
      * @param msg the message to store
      * @throws IOException If a failure happens writing the message
      * @throws MessagingException If a failure happens reading the message
@@ -288,54 +298,72 @@ public class RetrieveMessageReceiver extends AbstractPollingMessageReceiver impl
     @Override
     public synchronized void poll()
     {
-        try
+        boolean done = false;
+        while (!done)
         {
+            if (getLifecycleState().isStopping())
+            {
+                break;
+            }
             try
             {
-                if (!folder.isOpen())
+                try
                 {
-                    folder.open(Folder.READ_WRITE);
+                    if (!folder.isOpen())
+                    {
+                        folder.open(Folder.READ_WRITE);
+                    }
                 }
-            }
-            catch (Exception e)
-            {
-                if (logger.isDebugEnabled())
+                catch (Exception e)
                 {
-                    logger.debug("ignoring exception: " + e.getMessage());
+                    if (logger.isDebugEnabled())
+                    {
+                        logger.debug("ignoring exception: " + e.getMessage());
+                    }
                 }
-            }
 
-            int count = folder.getMessageCount();
-            if (count > 0)
-            {
-                Message[] messages = folder.getMessages();
-                MessageCountEvent event = new MessageCountEvent(folder, MessageCountEvent.ADDED, true,
-                    messages);
-                messagesAdded(event);
+                int count = folder.getMessageCount();
+                int batchSize = getBatchSize(count);
+                if (count > 0)
+                {
+                    Message[] messages = folder.getMessages(1, batchSize);
+                    MessageCountEvent event = new MessageCountEvent(folder, MessageCountEvent.ADDED, true,
+                        messages);
+                    messagesAdded(event);
+                }
+                else if (count == -1)
+                {
+                    throw new MessagingException("Cannot monitor folder: " + folder.getFullName()
+                        + " as folder is closed");
+                }
+                done = batchSize >= count;
             }
-            else if (count == -1)
+            catch (MessagingException e)
             {
-                throw new MessagingException("Cannot monitor folder: " + folder.getFullName()
-                                             + " as folder is closed");
+                done = true;
+                getConnector().getMuleContext().getExceptionListener().handleException(e);
             }
-        }
-        catch (MessagingException e)
-        {
-            getConnector().getMuleContext().getExceptionListener().handleException(e);
-        }
-        finally
-        {
-            try
+            finally
             {
-                folder.close(true); // close and expunge deleted messages
-            }
-            catch (Exception e)
-            {
-                logger.error("Failed to close pop3  inbox: " + e.getMessage());
+                try
+                {
+                    folder.close(true); // close and expunge deleted messages
+                }
+                catch (Exception e)
+                {
+                    logger.error("Failed to close pop3  inbox: " + e.getMessage());
+                }
             }
         }
     }
 
+
+    @Override
+    protected boolean pollOnPrimaryInstanceOnly()
+    {
+        return true;
+    }
+
     @Override
     protected void doDispose()
     {
