@@ -1,5 +1,5 @@
 /*
- * $Id: JmsConnector.java 21645 2011-03-31 20:35:42Z pablo.kraan $
+ * $Id: JmsConnector.java 22763 2011-08-26 22:30:12Z svacas $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -19,7 +19,7 @@ import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.lifecycle.StartException;
-import org.mule.api.lifecycle.StopException;
+import org.mule.api.processor.MessageProcessor;
 import org.mule.api.transaction.Transaction;
 import org.mule.api.transaction.TransactionException;
 import org.mule.api.transport.ReplyToHandler;
@@ -28,9 +28,11 @@ import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.MessageFactory;
 import org.mule.context.notification.ConnectionNotification;
 import org.mule.context.notification.NotificationException;
+import org.mule.endpoint.AbstractEndpoint;
 import org.mule.transaction.TransactionCoordination;
 import org.mule.transport.AbstractConnector;
 import org.mule.transport.ConnectException;
+import org.mule.transport.jms.filters.JmsSelectorFilter;
 import org.mule.transport.jms.i18n.JmsMessages;
 import org.mule.transport.jms.jndi.JndiNameResolver;
 import org.mule.transport.jms.jndi.SimpleJndiNameResolver;
@@ -41,6 +43,7 @@ import org.mule.util.BeanUtils;
 
 import java.text.MessageFormat;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
@@ -55,8 +58,6 @@ import javax.jms.XAConnectionFactory;
 import javax.naming.CommunicationException;
 import javax.naming.NamingException;
 
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicInteger;
-
 /**
  * <code>JmsConnector</code> is a JMS 1.0.2b compliant connector that can be used
  * by a Mule endpoint. The connector supports all JMS functionality including topics
@@ -477,8 +478,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
         if (receiverReportedExceptionCount.incrementAndGet() >= expectedReceiverCount)
         {
             receiverReportedExceptionCount.set(0);
-
-            handleException(new ConnectException(jmsException, this));
+            muleContext.getExceptionListener().handleException(new ConnectException(jmsException, this));
         }
     }
 
@@ -643,7 +643,9 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
             }
             catch (JMSException e)
             {
-                throw new StopException(CoreMessages.failedToStop("Jms Connection"), e, this);
+                // this exception may be thrown when the broker is shut down, but the
+                // stop process should continue all the same
+                logger.warn("Jms connection failed to stop properly: ", e);
             }
         }
 
@@ -656,7 +658,7 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     @Override
     public ReplyToHandler getReplyToHandler(ImmutableEndpoint endpoint)
     {
-        return new JmsReplyToHandler(this, getDefaultResponseTransformers(endpoint));
+        return new JmsReplyToHandler(this);
     }
 
     /**
@@ -787,13 +789,20 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
      */
     public void closeQuietly(Session session)
     {
-        try
+        if (session != null)
         {
-            close(session);
-        }
-        catch (JMSException e)
-        {
-            logger.warn("Failed to close jms session consumer: " + e.getMessage());
+            try
+            {
+                close(session);
+            }
+            catch (JMSException e)
+            {
+                logger.warn("Failed to close jms session consumer: " + e.getMessage());
+            }
+            finally
+            {
+                session = null;
+            }
         }
     }
 
@@ -1328,4 +1337,17 @@ public class JmsConnector extends AbstractConnector implements ExceptionListener
     {
         this.sameRMOverrideValue = sameRMOverrideValue;
     }
+
+    public JmsSelectorFilter getSelector(ImmutableEndpoint endpoint)
+    {
+        for (MessageProcessor mp : endpoint.getMessageProcessors())
+        {
+            if (mp instanceof JmsSelectorFilter)
+            {
+                return (JmsSelectorFilter) mp;
+            }
+        }
+
+        return null;
+    }
 }
