@@ -1,5 +1,5 @@
 /*
- * $Id: JmsExceptionReaderTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: JmsExceptionReaderTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,8 +13,7 @@ package org.mule.transport.jms;
 import org.mule.api.DefaultMuleException;
 import org.mule.config.ExceptionHelper;
 import org.mule.config.i18n.MessageFactory;
-import org.mule.tck.AbstractMuleTestCase;
-import org.mule.transport.jms.JmsExceptionReader;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 
 import java.io.IOException;
 import java.util.List;
@@ -22,14 +21,23 @@ import java.util.Map;
 
 import javax.jms.JMSException;
 
+import org.junit.Before;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+
 public class JmsExceptionReaderTestCase extends AbstractMuleTestCase
 {
 
-    protected void doSetUp() throws Exception
+    @Before
+    public void registerExceptionReader()
     {
         ExceptionHelper.registerExceptionReader(new JmsExceptionReader());
     }
 
+    @Test
     public void testNestedExceptionRetrieval() throws Exception
     {
         Exception testException = getException();
