@@ -1,5 +1,5 @@
 /*
- * $Id: JmsRedeliveryTestCase.java 20501 2010-12-08 00:52:19Z tcarlson $
+ * $Id: JmsRedeliveryTestCase.java 22772 2011-08-27 15:20:15Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,36 +10,52 @@
 
 package org.mule.transport.jms;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
 import org.mule.api.MuleEventContext;
-import org.mule.api.MuleMessage;
 import org.mule.api.client.MuleClient;
 import org.mule.api.context.notification.ExceptionNotificationListener;
 import org.mule.context.notification.ExceptionNotification;
-import org.mule.message.ExceptionMessage;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.tck.exceptions.FunctionalTestException;
 import org.mule.tck.functional.CounterCallback;
 import org.mule.tck.functional.FunctionalTestComponent;
 import org.mule.transport.jms.redelivery.MessageRedeliveredException;
 import org.mule.util.concurrent.Latch;
 
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.concurrent.TimeUnit;
 
-public class JmsRedeliveryTestCase extends FunctionalTestCase
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+public class JmsRedeliveryTestCase extends AbstractServiceAndFlowTestCase
 {
+
     private final int timeout = getTestTimeoutSecs() * 1000 / 4;
     private static final String DESTINATION = "jms://in";
     private static final int MAX_REDELIVERY = 3;
 
-    protected String getConfigResources()
+    public JmsRedeliveryTestCase(ConfigVariant variant, String configResources)
     {
-        return "jms-redelivery.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{{ConfigVariant.SERVICE, "jms-redelivery-service.xml"},
+            {ConfigVariant.FLOW, "jms-redelivery-flow.xml"}});
+    }
+
+    @Test
     public void testRedelivery() throws Exception
     {
         MuleClient client = muleContext.getClient();
-        // required if broker is not restarted with the test - it tries to deliver those messages to the client
+        // required if broker is not restarted with the test - it tries to deliver those messages to the
+        // client
         // purge the queue
         while (client.request(DESTINATION, 1000) != null)
         {
@@ -54,13 +70,19 @@ public class JmsRedeliveryTestCase extends FunctionalTestCase
         {
             public void onNotification(ExceptionNotification notification)
             {
+                logger.debug("onNotification() = " + notification.getException().getClass().getName());
                 if (notification.getException() instanceof MessageRedeliveredException)
                 {
                     mrexFired.countDown();
                     // Test for MULE-4630
-                    assertEquals(DESTINATION, ((MessageRedeliveredException) notification.getException()).getEndpoint().getEndpointURI().toString());
-                    assertEquals(MAX_REDELIVERY, ((MessageRedeliveredException) notification.getException()).getMaxRedelivery());
-                    assertTrue(((MessageRedeliveredException) notification.getException()).getMuleMessage().getPayload() instanceof javax.jms.Message);
+                    assertEquals(DESTINATION,
+                        ((MessageRedeliveredException) notification.getException()).getEndpoint()
+                            .getEndpointURI()
+                            .toString());
+                    assertEquals(MAX_REDELIVERY,
+                        ((MessageRedeliveredException) notification.getException()).getMaxRedelivery());
+                    assertTrue(((MessageRedeliveredException) notification.getException()).getMuleMessage()
+                        .getPayload() instanceof javax.jms.Message);
                 }
             }
         });
@@ -72,7 +94,7 @@ public class JmsRedeliveryTestCase extends FunctionalTestCase
             public void eventReceived(MuleEventContext context, Object Component) throws Exception
             {
                 final int count = incCallbackCount();
-                logger.info("Message Delivery Count is: " + count); 
+                logger.info("Message Delivery Count is: " + count);
                 throw new FunctionalTestException();
             }
         };
@@ -85,11 +107,5 @@ public class JmsRedeliveryTestCase extends FunctionalTestCase
         assertEquals("MessageRedeliveredException never fired.", 0, mrexFired.getCount());
         assertEquals("Wrong number of delivery attempts", MAX_REDELIVERY + 1, callback.getCallbackCount());
 
-        MuleMessage dl = client.request("jms://dead.letter", 1000);
-        assertNotNull(dl);
-        assertTrue(dl.getPayload() instanceof ExceptionMessage);
-        ExceptionMessage em = (ExceptionMessage) dl.getPayload();
-        assertNotNull(em.getException());
-        assertTrue(em.getException() instanceof MessageRedeliveredException);
     }
 }
