@@ -1,5 +1,5 @@
 /*
- * $Id: QuartzCustomJobFromMessageTestCase.java 21823 2011-05-06 04:22:11Z dirk.olmes $
+ * $Id: QuartzCustomJobFromMessageTestCase.java 22498 2011-07-21 13:01:39Z justin.calleja $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,24 +10,40 @@
 
 package org.mule.transport.quartz;
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Map;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
 import org.mule.api.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.tck.functional.CountdownCallback;
 import org.mule.tck.functional.FunctionalTestComponent;
 import org.mule.transport.NullPayload;
 import org.mule.transport.quartz.jobs.ScheduledDispatchJobConfig;
 
-import java.util.HashMap;
-import java.util.Map;
-
-public class QuartzCustomJobFromMessageTestCase extends FunctionalTestCase
+public class QuartzCustomJobFromMessageTestCase extends AbstractServiceAndFlowTestCase
 {
-    @Override
-    protected String getConfigResources()
+
+    public QuartzCustomJobFromMessageTestCase(ConfigVariant variant, String configResources)
     {
-        return "quartz-receive-dispatch-delegating-job.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "quartz-receive-dispatch-delegating-job-service.xml"},
+            {ConfigVariant.FLOW, "quartz-receive-dispatch-delegating-job-flow.xml"}});
+    }
+
+    @Test
     public void testDelegatingJobAsProperty() throws Exception
     {
         FunctionalTestComponent component = (FunctionalTestComponent) getComponent("scheduledService");
@@ -45,11 +61,14 @@ public class QuartzCustomJobFromMessageTestCase extends FunctionalTestCase
         client.dispatch("vm://quartz.scheduler1", NullPayload.getInstance(), props);
         assertTrue(count.await(7000));
 
-        // now that the scheduler sent the event, null out the event callback to avoid CountdownCallback
-        // report more messages than requested during shutdown of the test/Mule server
+        // now that the scheduler sent the event, null out the event callback to
+        // avoid CountdownCallback
+        // report more messages than requested during shutdown of the test/Mule
+        // server
         component.setEventCallback(null);
     }
 
+    @Test
     public void testDelegatingJobAsPayload() throws Exception
     {
         FunctionalTestComponent component = (FunctionalTestComponent) getComponent("scheduledService");
@@ -65,8 +84,10 @@ public class QuartzCustomJobFromMessageTestCase extends FunctionalTestCase
         client.dispatch("vm://quartz.scheduler2", jobConfig, null);
         assertTrue(count.await(7000));
 
-        // now that the scheduler sent the event, null out the event callback to avoid CountdownCallback
-        // report more messages than requested during shutdown of the test/Mule server
+        // now that the scheduler sent the event, null out the event callback to
+        // avoid CountdownCallback
+        // report more messages than requested during shutdown of the test/Mule
+        // server
         component.setEventCallback(null);
     }
 }
