@@ -1,5 +1,5 @@
 /*
- * $Id: JettyHttpFunctionalTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: JettyHttpFunctionalTestCase.java 22518 2011-07-22 07:00:22Z claude.mamo $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,23 +10,39 @@
 
 package org.mule.transport.servlet.jetty;
 
+import static org.junit.Assert.assertEquals;
+
 import org.mule.api.MuleMessage;
 import org.mule.api.client.LocalMuleClient;
 import org.mule.transport.http.HttpConstants;
 import org.mule.transport.http.functional.HttpFunctionalTestCase;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
 public class JettyHttpFunctionalTestCase extends HttpFunctionalTestCase
 {
 
-    @Override
-    protected String getConfigResources()
+    public JettyHttpFunctionalTestCase(ConfigVariant variant, String configResources)
     {
-        return "jetty-http-functional-test.xml";
+        super(variant, configResources);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "jetty-http-functional-test-service.xml"},
+            {ConfigVariant.FLOW, "jetty-http-functional-test-flow.xml"}
+        });
+    }      
+    
+    @Test
     public void testNonRootUrls() throws Exception
     {
         LocalMuleClient client = muleContext.getClient();
@@ -36,5 +52,4 @@ public class JettyHttpFunctionalTestCase extends HttpFunctionalTestCase
         assertEquals(TEST_MESSAGE + " Received", result.getPayloadAsString());
     }
 
-
 }
