@@ -1,5 +1,5 @@
 /*
- * $Id: TcpConnector.java 20568 2010-12-09 20:03:04Z aperepel $
+ * $Id: TcpConnector.java 22665 2011-08-15 06:33:46Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -53,6 +53,7 @@ public class TcpConnector extends AbstractConnector
     public static final int DEFAULT_SO_LINGER = INT_VALUE_NOT_SET;
     public static final int DEFAULT_BUFFER_SIZE = INT_VALUE_NOT_SET;
     public static final int DEFAULT_BACKLOG = INT_VALUE_NOT_SET;
+    public static final int DEFAULT_WAIT_TIMEOUT = INT_VALUE_NOT_SET;
 
     // to clarify arg to configureSocket
     public static final boolean SERVER = false;
@@ -60,6 +61,7 @@ public class TcpConnector extends AbstractConnector
 
     private int clientSoTimeout = DEFAULT_SOCKET_TIMEOUT;
     private int serverSoTimeout = DEFAULT_SOCKET_TIMEOUT;
+    private int socketMaxWait = DEFAULT_WAIT_TIMEOUT;
     private int sendBufferSize = DEFAULT_BUFFER_SIZE;
     private int receiveBufferSize = DEFAULT_BUFFER_SIZE;
     private int receiveBacklog = DEFAULT_BACKLOG;
@@ -152,16 +154,23 @@ public class TcpConnector extends AbstractConnector
         socketsPool.setFactory(getSocketFactory());
         socketsPool.setTestOnBorrow(true);
         socketsPool.setTestOnReturn(true);
-        //There should only be one pooled instance per socket (key)
-        socketsPool.setMaxActive(1);
+        setMaxSocketActive();
         socketsPool.setWhenExhaustedAction(GenericKeyedObjectPool.WHEN_EXHAUSTED_BLOCK);
+        socketsPool.setMaxWait(socketMaxWait);
 
         // Use connector's classloader so that other temporary classloaders
         // aren't used when things are started lazily or from elsewhere.
         final String monitorName = String.format("%s%s.socket",
                                                  ThreadNameHelper.getPrefix(muleContext),
                                                  getName());
-        keepAliveMonitor = new ExpiryMonitor(monitorName, 1000, this.getClass().getClassLoader());
+        keepAliveMonitor = new ExpiryMonitor(monitorName, 1000, this.getClass().getClassLoader(), muleContext, false);
+    }
+
+    private void setMaxSocketActive()
+    {
+        int maxActive = getDispatcherThreadingProfile().getMaxThreadsActive();
+        socketsPool.setMaxActive(maxActive);
+        socketsPool.setMaxIdle(maxActive);
     }
 
     @Override
@@ -326,6 +335,16 @@ public class TcpConnector extends AbstractConnector
         this.serverSoTimeout = valueOrDefault(timeout, 0, DEFAULT_SOCKET_TIMEOUT);
     }
 
+    public int getSocketMaxWait()
+    {
+        return socketMaxWait;
+    }
+
+    public void setSocketMaxWait(int timeout)
+    {
+        this.socketMaxWait = valueOrDefault(timeout, 0, DEFAULT_WAIT_TIMEOUT);
+    }
+
     /** @deprecated Should use {@link #getSendBufferSize()} or {@link #getReceiveBufferSize()} */
     @Deprecated
     public int getBufferSize()
@@ -523,4 +542,25 @@ public class TcpConnector extends AbstractConnector
     {
         return dispatchers;
     }
+
+    public int getSocketsPoolMaxActive()
+    {
+        return socketsPool.getMaxActive();
+    }
+
+    public int getSocketsPoolMaxIdle()
+    {
+        return socketsPool.getMaxIdle();
+    }
+
+    public int getSocketsPoolNumActive()
+    {
+        return socketsPool.getNumActive();
+    }
+
+    public long getSocketsPoolMaxWait()
+    {
+        return socketsPool.getMaxWait();
+    }
+
 }
