@@ -1,5 +1,5 @@
 /*
- * $Id: KeepSendSocketOpenMule1491TestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: KeepSendSocketOpenMule1491TestCase.java 22461 2011-07-20 07:48:55Z justin.calleja $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,32 +10,55 @@
 
 package org.mule.transport.tcp.issues;
 
-import org.mule.api.MuleMessage;
-import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
-import org.mule.transport.tcp.protocols.LengthProtocol;
+import static org.junit.Assert.assertEquals;
 
 import java.io.BufferedInputStream;
 import java.io.InputStream;
 import java.net.InetSocketAddress;
 import java.net.ServerSocket;
 import java.net.Socket;
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicInteger;
 
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicBoolean;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicInteger;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+import org.mule.api.MuleMessage;
+import org.mule.module.client.MuleClient;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
+import org.mule.transport.tcp.protocols.LengthProtocol;
 
-public class KeepSendSocketOpenMule1491TestCase extends DynamicPortTestCase 
+public class KeepSendSocketOpenMule1491TestCase extends AbstractServiceAndFlowTestCase
 {
     protected static String TEST_TCP_MESSAGE = "Test TCP Request";
 
-    @Override
-    protected String getConfigResources()
+    @Rule
+    public DynamicPort dynamicPort1 = new DynamicPort("port1");
+
+    @Rule
+    public DynamicPort dynamicPort2 = new DynamicPort("port2");
+
+    @Rule
+    public DynamicPort dynamicPort3 = new DynamicPort("port3");
+
+    public KeepSendSocketOpenMule1491TestCase(ConfigVariant variant, String configResources)
     {
-        return "tcp-keep-send-socket-open.xml";
+        super(variant, configResources);
+    }
+        
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{{ConfigVariant.SERVICE, "tcp-keep-send-socket-open-service.xml"},
+            {ConfigVariant.FLOW, "tcp-keep-send-socket-open-flow.xml"}});
     }
 
+    @Test
     public void testSend() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -66,14 +89,16 @@ public class KeepSendSocketOpenMule1491TestCase extends DynamicPortTestCase
         }
     }
 
+    @Test
     public void testOpen() throws Exception
     {
-        useServer("tcp://localhost:" + getPorts().get(1) + "?connector=openConnectorLength", getPorts().get(1), 1);
+        useServer("tcp://localhost:" + dynamicPort2.getNumber() + "?connector=openConnectorLength", dynamicPort2.getNumber(), 1);
     }
 
+    @Test
     public void testClose() throws Exception
     {
-        useServer("tcp://localhost:" + getPorts().get(2) + "?connector=closeConnectorLength", getPorts().get(2), 2);
+        useServer("tcp://localhost:" + dynamicPort3.getNumber() + "?connector=closeConnectorLength", dynamicPort3.getNumber(), 2);
     }
 
     @SuppressWarnings("synthetic-access")
@@ -95,6 +120,7 @@ public class KeepSendSocketOpenMule1491TestCase extends DynamicPortTestCase
             return count.get();
         }
 
+        @Override
         public void run()
         {
             try
@@ -144,10 +170,4 @@ public class KeepSendSocketOpenMule1491TestCase extends DynamicPortTestCase
             }
         }
     }
-
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 3;
-    }
 }
