@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultProtocolTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: DefaultProtocolTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,9 +10,12 @@
 
 package org.mule.transport.tcp.protocols;
 
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 import org.mule.transport.tcp.TcpProtocol;
-import org.mule.transport.tcp.protocols.DirectProtocol;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
 
 public class DefaultProtocolTestCase extends AbstractMuleTestCase
 {
@@ -28,13 +31,13 @@ public class DefaultProtocolTestCase extends AbstractMuleTestCase
         this(new DirectProtocol(), SlowInputStream.FULL_LENGTH);
     }
 
-    public DefaultProtocolTestCase(TcpProtocol protocol, int expectedLength)
+    protected DefaultProtocolTestCase(TcpProtocol protocol, int expectedLength)
     {
         this.protocol = protocol;
         this.expectedLength = expectedLength;
     }
 
-
+    @Test
     public void testRead() throws Exception
     {
         byte[] result = (byte[]) protocol.read(new SlowInputStream());
