@@ -1,5 +1,5 @@
 /*
- * $Id: UdpNamespaceHandlerTestCase.java 21142 2011-01-27 18:38:34Z mike.schilling $
+ * $Id: UdpNamespaceHandlerTestCase.java 22431 2011-07-18 07:40:35Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -9,19 +9,24 @@
  */
 package org.mule.transport.udp;
 
-import org.mule.tck.FunctionalTestCase;
-import org.mule.transport.udp.UdpConnector;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 
-/**
- * TODO
- */
 public class UdpNamespaceHandlerTestCase extends FunctionalTestCase
 {
+
+    @Override
     protected String getConfigResources()
     {
         return "udp-namespace-config.xml";
     }
 
+    @Test
     public void testConfig() throws Exception
     {
         UdpConnector c = (UdpConnector)muleContext.getRegistry().lookupConnector("udpConnector");
