@@ -1,5 +1,5 @@
 /*
- * $Id: VMMessageDispatcher.java 19749 2010-09-28 04:37:54Z dirk.olmes $
+ * $Id: VMMessageDispatcher.java 22686 2011-08-16 19:39:20Z pablo.lagreca $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,6 +10,7 @@
 
 package org.mule.transport.vm;
 
+import org.mule.DefaultMuleEvent;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleMessage;
 import org.mule.api.endpoint.EndpointURI;
@@ -46,15 +47,17 @@ public class VMMessageDispatcher extends AbstractMessageDispatcher
         if (endpointUri == null)
         {
             throw new DispatchException(CoreMessages.objectIsNull("Endpoint"), event,
-                (OutboundEndpoint) endpoint);
+                getEndpoint());
         }
+        MuleMessage newMessage = event.getMessage().createInboundMessage();
+        MuleEvent newEvent = new DefaultMuleEvent(newMessage, event);
         QueueSession session = connector.getQueueSession();
         Queue queue = session.getQueue(endpointUri.getAddress());
-        if (!queue.offer(event, connector.getQueueTimeout()))
+        if (!queue.offer(newEvent, connector.getQueueTimeout()))
         {
             // queue is full
             throw new DispatchException(VMMessages.queueIsFull(queue.getName(), queue.size()),
-                    event, (OutboundEndpoint) endpoint);
+                    newEvent, getEndpoint());
         }
         if (logger.isDebugEnabled())
         {
@@ -66,18 +69,16 @@ public class VMMessageDispatcher extends AbstractMessageDispatcher
     protected MuleMessage doSend(final MuleEvent event) throws Exception
     {
         MuleMessage retMessage;
-        EndpointURI endpointUri = event.getEndpoint().getEndpointURI();
-        final VMMessageReceiver receiver = connector.getReceiver(endpointUri);
+        final VMMessageReceiver receiver = connector.getReceiver(endpoint.getEndpointURI());
         // Apply any outbound transformers on this event before we dispatch
 
         if (receiver == null)
         {
             throw new NoReceiverForEndpointException(VMMessages.noReceiverForEndpoint(connector.getName(),
-                                                                                      event.getEndpoint().getEndpointURI()));
+                                                                                      endpoint.getEndpointURI()));
         }
 
-        MuleMessage message = event.getMessage();
-        connector.getSessionHandler().storeSessionInfoToMessage(event.getSession(), message);
+        final MuleMessage message = event.getMessage().createInboundMessage();
         TransactionTemplate<MuleMessage> tt = new TransactionTemplate<MuleMessage>(
                                                             receiver.getEndpoint().getTransactionConfig(),
                                                             event.getMuleContext());
@@ -86,14 +87,18 @@ public class VMMessageDispatcher extends AbstractMessageDispatcher
         {
             public MuleMessage doInTransaction() throws Exception
             {
-                return receiver.onCall(event.getMessage());
+                return receiver.onCall(message);
             }
         };
         retMessage = tt.execute(cb);
         
         if (logger.isDebugEnabled())
         {
-            logger.debug("sent event on endpointUri: " + event.getEndpoint().getEndpointURI());
+            logger.debug("sent event on endpointUri: " +endpoint.getEndpointURI());
+        }
+        if (retMessage != null)
+        {
+            retMessage = retMessage.createInboundMessage();
         }
         return retMessage;
     }
@@ -111,7 +116,7 @@ public class VMMessageDispatcher extends AbstractMessageDispatcher
         {
             // use the default queue profile to configure this queue.
             connector.getQueueProfile().configureQueue(
-                    endpoint.getEndpointURI().getAddress(), connector.getQueueManager());
+                    connector.getMuleContext(), endpoint.getEndpointURI().getAddress(), connector.getQueueManager());
         }
     }
 
