@@ -1,5 +1,5 @@
 /*
- * $Id: ExceptionUtilsTestCase.java 19229 2010-08-26 20:50:55Z tcarlson $
+ * $Id: ExceptionUtilsTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,15 +10,22 @@
 
 package org.mule.util;
 
-import static org.mule.util.ExceptionUtils.containsType;
-import static org.mule.util.ExceptionUtils.getDeepestOccurenceOfType;
-
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 
 import java.io.IOException;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
+import static org.mule.util.ExceptionUtils.containsType;
+import static org.mule.util.ExceptionUtils.getDeepestOccurenceOfType;
+
 public class ExceptionUtilsTestCase extends AbstractMuleTestCase
 {
+    @Test
     public void testContainsType()
     {
         assertTrue(containsType(new IllegalArgumentException(), IllegalArgumentException.class));
@@ -34,12 +41,14 @@ public class ExceptionUtilsTestCase extends AbstractMuleTestCase
         assertFalse(containsType(new Exception(new IllegalArgumentException(new NullPointerException())), IOException.class));
     }
 
+    @Test
     public void testLastIndexOfType_deepestIsTheOneWeWant() throws Exception
     {
         IllegalArgumentException expected = new IllegalArgumentException("something");
         assertExpectationsForDeepestOccurence(expected);
     }
 
+    @Test
     public void testLastIndexOfType_theOneWeWantIsNotTheDeepest() throws Exception
     {
         IllegalArgumentException expected = new IllegalArgumentException("something", new NullPointerException("somenull"));
@@ -59,6 +68,7 @@ public class ExceptionUtilsTestCase extends AbstractMuleTestCase
         assertNull(getDeepestOccurenceOfType(new IllegalArgumentException(new Exception(expected)), IOException.class));
     }
 
+    @Test
     public void testLastIndexOfType_nullParameters() throws Exception
     {
         assertNull(getDeepestOccurenceOfType(null, null));
