@@ -1,5 +1,5 @@
 /*
- * $Id: MulticasterTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: MulticasterTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,7 +10,7 @@
 
 package org.mule.util;
 
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleTestCase;
 import org.mule.tck.testmodels.fruit.Apple;
 import org.mule.tck.testmodels.fruit.Banana;
 import org.mule.tck.testmodels.fruit.Fruit;
@@ -19,9 +19,14 @@ import org.mule.tck.testmodels.fruit.WaterMelon;
 import java.util.ArrayList;
 import java.util.List;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertTrue;
+
 public class MulticasterTestCase extends AbstractMuleTestCase
 {
 
+    @Test
     public void testMulticating() throws Exception
     {
         List fruit = new ArrayList();
