@@ -1,5 +1,5 @@
 /*
- * $Id: PropertiesUtils.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: PropertiesUtils.java 21939 2011-05-18 13:32:09Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -21,8 +21,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
-
-import edu.emory.mathcs.backport.java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.CopyOnWriteArrayList;
 
 /**
  * <code>PropertiesHelper</code> is a utility class for manipulating and filtering
