@@ -1,5 +1,5 @@
 /*
- * $Id: QueueManager.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: QueueManager.java 22409 2011-07-14 05:14:27Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -14,30 +14,14 @@ import org.mule.api.lifecycle.Startable;
 import org.mule.api.lifecycle.Stoppable;
 
 /**
- * A Queue manager is responsible for manageing one or more Queue resources and
- * providing common support fot transactions and persistence
+ * A Queue manager is responsible for managing one or more Queue resources and
+ * providing common support for transactions and persistence.
  */
 public interface QueueManager extends Startable, Stoppable
 {
-
     QueueSession getQueueSession();
 
     void setDefaultQueueConfiguration(QueueConfiguration config);
 
     void setQueueConfiguration(String queueName, QueueConfiguration config);
-
-    /**
-     * @return Returns the persistenceStrategy.
-     */
-    QueuePersistenceStrategy getPersistenceStrategy();
-
-    /**
-     * @param persistenceStrategy The persistenceStrategy to set.
-     */
-    void setPersistenceStrategy(QueuePersistenceStrategy persistenceStrategy);
-
-    QueuePersistenceStrategy getMemoryPersistenceStrategy();
-
-    void setMemoryPersistenceStrategy(QueuePersistenceStrategy memoryPersistenceStrategy);
-
 }
